/* 
 * Copyright (c) Tony Bybell 1999-2007.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 */

#include "globals.h"
#include <config.h>
#include "pixmaps.h"

/* XPM */
static char * icon_redo[] = {
"24 24 126 2",
"  	c None",
". 	c #000000",
"+ 	c #F0FFEE",
"@ 	c #CAE3C6",
"# 	c #F5FFF4",
"$ 	c #0D110C",
"% 	c #729C6C",
"& 	c #A6CAA1",
"* 	c #CBE4C7",
"= 	c #EFFDEE",
"- 	c #172116",
"; 	c #88B583",
"> 	c #CCE5C8",
", 	c #CDE6C9",
"' 	c #CFE7CB",
") 	c #F3FFF2",
"! 	c #7FA879",
"~ 	c #689063",
"{ 	c #CDE5C9",
"] 	c #CFE7CA",
"^ 	c #D0E9CC",
"/ 	c #D4EAD0",
"( 	c #D5ECD1",
"_ 	c #AED5A9",
": 	c #9ABC95",
"< 	c #63865F",
"[ 	c #2B3A29",
"} 	c #8CB887",
"| 	c #70986A",
"1 	c #71986B",
"2 	c #729A6B",
"3 	c #759C6D",
"4 	c #759F6F",
"5 	c #76A170",
"6 	c #567453",
"7 	c #AFCBAC",
"8 	c #7EAB77",
"9 	c #78A472",
"0 	c #6F9669",
"a 	c #70976A",
"b 	c #71996B",
"c 	c #739B6D",
"d 	c #759F6E",
"e 	c #77A170",
"f 	c #526F4C",
"g 	c #B7D2B2",
"h 	c #60835B",
"i 	c #A5C9A0",
"j 	c #9AC195",
"k 	c #4F6B4C",
"l 	c #769F70",
"m 	c #516D4C",
"n 	c #B9D5B4",
"o 	c #7BA574",
"p 	c #C7E0C3",
"q 	c #6D9568",
"r 	c #51714E",
"s 	c #B6D3B2",
"t 	c #81AB7C",
"u 	c #C3DBBF",
"v 	c #6B9265",
"w 	c #C8EFC3",
"x 	c #A7CCA2",
"y 	c #B5D2B1",
"z 	c #80A87A",
"A 	c #90B68B",
"B 	c #79A674",
"C 	c #C6EAC1",
"D 	c #DEF7D9",
"E 	c #B3D7AE",
"F 	c #BBD9B8",
"G 	c #AFCCAB",
"H 	c #749E6D",
"I 	c #5B7B57",
"J 	c #8CB087",
"K 	c #BBE1B6",
"L 	c #DAF5D6",
"M 	c #E1F7DD",
"N 	c #DCF4D6",
"O 	c #D7F0D3",
"P 	c #CFECCB",
"Q 	c #C6E3C3",
"R 	c #BCD6B9",
"S 	c #7EA778",
"T 	c #64885F",
"U 	c #A6C1A3",
"V 	c #B3D5AE",
"W 	c #CDEAC9",
"X 	c #D0EBCB",
"Y 	c #CAE9C5",
"Z 	c #C7E6C3",
"` 	c #C3E3BF",
" .	c #BDDCBA",
"..	c #B5D2B2",
"+.	c #96B991",
"@.	c #76A071",
"#.	c #3A4E37",
"$.	c #5E7F5A",
"%.	c #8FAF8B",
"&.	c #9CBE97",
"*.	c #C7E0C4",
"=.	c #CBE3C6",
"-.	c #CDE4C9",
";.	c #CBE4C8",
">.	c #C7E1C4",
",.	c #C2DBBF",
"'.	c #88AF82",
").	c #6B9266",
"!.	c #557451",
"~.	c #63885E",
"{.	c #759C70",
"].	c #749E6F",
"^.	c #72996B",
"/.	c #739A6D",
"(.	c #71996C",
"_.	c #6E9668",
":.	c #6C9367",
"<.	c #5F815A",
"[.	c #70996B",
"}.	c #6E9467",
"|.	c #698F63",
"1.	c #6B9166",
"2.	c #5D8059",
"3.	c #4D6A49",
"4.	c #6A8F64",
"5.	c #283926",
"              .                                 ",
"              . .                               ",
"              . + .                             ",
"        . . . . @ # .                           ",
"      $ % & @ @ * * = .           . .           ",
"    - ; @ @ * * > , ' ) .       . ! ~ .         ",
"  . % @ * * > { ] ^ / ( _ .       . : < .       ",
"  [ & @ } | 1 2 3 4 5 6 .           . 7 .       ",
". 8 @ 9 0 a b c d e f .             . g h .     ",
". i j 0 k . . . l m .       .       . n o .     ",
". p q h .     . r .       . .       . s t .     ",
". u v .       . .       . w .     . x y z .     ",
". A B .       .       . C D . . . E F G H .     ",
". I J .             . K L M N O P Q R S T .     ",
"  . U .           . V W X Y Z `  ...+.@.#..     ",
"  . $.%..       . &.*.=., -.;.>.,.'.).!..       ",
"    . ~.{..       . ].^.c /.(.| _.:.<.. .       ",
"      . .           . [.}.|.~ 1.2.3.. .         ",
"                      . q 4.. . . .             ",
"                        5.)..                   ",
"                          . .                   ",
"                            .                   ",
"                                                ",
"                                                "};

/* XPM */
static char * icon_larrow[] = {
"24 24 43 1",
" 	c None",
".	c #000000",
"+	c #B9D0B9",
"@	c #CDDECB",
"#	c #B6C7B6",
"$	c #B1C9B0",
"%	c #B3C4B3",
"&	c #B4CBB2",
"*	c #B5CEB5",
"=	c #B7CCB5",
"-	c #B9CEB7",
";	c #BAD1BA",
">	c #BBCFBA",
",	c #BBD0B9",
"'	c #B2C9B0",
")	c #7EAB78",
"!	c #AAC7A8",
"~	c #B3CAB1",
"{	c #B0C9B0",
"]	c #B0C9AE",
"^	c #AEC7AC",
"/	c #AAC5A8",
"(	c #A9C4A7",
"_	c #698267",
":	c #2D2D2D",
"<	c #CFDFCC",
"[	c #ADC8AB",
"}	c #B0C7AE",
"|	c #ADC6AB",
"1	c #678C63",
"2	c #9BAD9A",
"3	c #85AE81",
"4	c #87AF84",
"5	c #87B083",
"6	c #88AF84",
"7	c #88B085",
"8	c #86AF82",
"9	c #547150",
"0	c #3C5235",
"a	c #5B7950",
"b	c #4A6342",
"c	c #3B5035",
"d	c #415639",
"                        ",
"                        ",
"                        ",
"            .           ",
"           ..           ",
"          .+.           ",
"         .@#.           ",
"        .@$%........    ",
"       .@&*=-;->,').    ",
"      .@!~{]^///^(_.    ",
"     :<[}||[!^^}^[1.    ",
"    .23444445645789.    ",
"     .0aaaaaaaaaaab.    ",
"      .0aaaaaaaaaab.    ",
"       .0aabccccccd.    ",
"        .0ab........    ",
"         .0b.           ",
"          .b.           ",
"           ..           ",
"            .           ",
"                        ",
"                        ",
"                        ",
"                        "};

/* XPM */
static char * icon_rarrow[] = {
"24 24 41 1",
" 	c None",
".	c #000000",
"+	c #8CA782",
"@	c #B1CDAE",
"#	c #77A16E",
"$	c #B4CEB1",
"%	c #ACC8A9",
"&	c #709867",
"*	c #C1D6BD",
"=	c #BDD3B8",
"-	c #BFD4BB",
";	c #C2D7BE",
">	c #B0CAAD",
",	c #B2CBB0",
"'	c #AAC7A8",
")	c #0F1308",
"!	c #AEC5A8",
"~	c #AEC8AD",
"{	c #ABC7A8",
"]	c #AAC6A7",
"^	c #A8C6A5",
"/	c #ADC8AD",
"(	c #A8C7A8",
"_	c #A5C4A3",
":	c #7F9F76",
"<	c #A6BFA0",
"[	c #ABC7AA",
"}	c #A7C5A4",
"|	c #A9C7A6",
"1	c #AFC8AD",
"2	c #A4C3A2",
"3	c #6B9060",
"4	c #778E6F",
"5	c #698D60",
"6	c #6B9063",
"7	c #445B2C",
"8	c #6B8661",
"9	c #5B7950",
"0	c #6C8562",
"a	c #65815C",
"b	c #506B46",
"                        ",
"                        ",
"                        ",
"           .            ",
"           ..           ",
"           .+.          ",
"           .@#.         ",
"    ........$%&.        ",
"    .*=-;;;;>,'&)       ",
"    .!~{{{]^'/(_:.      ",
"    .<[^}^|{%'{123.     ",
"    .45666666666657.    ",
"    .8999999999997.     ",
"    .099999999997.      ",
"    .abbbbbb9997.       ",
"    ........b97.        ",
"           .b7.         ",
"           .7.          ",
"           ..           ",
"           .            ",
"                        ",
"                        ",
"                        ",
"                        "};


/* XPM */
static char * icon_zoomin[] = {
"24 24 131 2",
"  	c None",
". 	c #343434",
"+ 	c #2D2D2D",
"@ 	c #292929",
"# 	c #262626",
"$ 	c #2E2E2E",
"% 	c #303030",
"& 	c #737373",
"* 	c #A1A1A1",
"= 	c #B4B4B4",
"- 	c #B2B2B2",
"; 	c #9D9D9D",
"> 	c #676767",
", 	c #202020",
"' 	c #1C1C1C",
") 	c #272727",
"! 	c #616161",
"~ 	c #CACACA",
"{ 	c #CFCFCF",
"] 	c #D0D0D0",
"^ 	c #CECECE",
"/ 	c #C9C9C9",
"( 	c #C1C1C1",
"_ 	c #A7A7A7",
": 	c #4C4C4C",
"< 	c #131313",
"[ 	c #222222",
"} 	c #757575",
"| 	c #D3D3D3",
"1 	c #DBDBDB",
"2 	c #E7E7E7",
"3 	c #EFEFEF",
"4 	c #F3F3F3",
"5 	c #F1F1F1",
"6 	c #E5E5E5",
"7 	c #D2D2D2",
"8 	c #BCBCBC",
"9 	c #5E5E5E",
"0 	c #101010",
"a 	c #212121",
"b 	c #5B5B5B",
"c 	c #CCCCCC",
"d 	c #D7D7D7",
"e 	c #F5F5F5",
"f 	c #FAFAFA",
"g 	c #FBFBFB",
"h 	c #F8F8F8",
"i 	c #F0F0F0",
"j 	c #E1E1E1",
"k 	c #C2C2C2",
"l 	c #434343",
"m 	c #0F0F0F",
"n 	c #1F1F1F",
"o 	c #B9B9B9",
"p 	c #D6D6D6",
"q 	c #F9F9F9",
"r 	c #FDFDFD",
"s 	c #FCFCFC",
"t 	c #F2F2F2",
"u 	c #ECECEC",
"v 	c #E4E4E4",
"w 	c #ABABAB",
"x 	c #0E0E0E",
"y 	c #1B1B1B",
"z 	c #6D6D6D",
"A 	c #FEFEFE",
"B 	c #EEEEEE",
"C 	c #E6E6E6",
"D 	c #575757",
"E 	c #090909",
"F 	c #141414",
"G 	c #A8A8A8",
"H 	c #D8D8D8",
"I 	c #F6F6F6",
"J 	c #F4F4F4",
"K 	c #DCDCDC",
"L 	c #9B9B9B",
"M 	c #060606",
"N 	c #111111",
"O 	c #C5C5C5",
"P 	c #DFDFDF",
"Q 	c #444444",
"R 	c #454545",
"S 	c #424242",
"T 	c #EDEDED",
"U 	c #BFBFBF",
"V 	c #C6C6C6",
"W 	c #E3E3E3",
"X 	c #414141",
"Y 	c #EAEAEA",
"Z 	c #E0E0E0",
"` 	c #BABABA",
" .	c #050505",
"..	c #0B0B0B",
"+.	c #A5A5A5",
"@.	c #D1D1D1",
"#.	c #939393",
"$.	c #020202",
"%.	c #0A0A0A",
"&.	c #5F5F5F",
"*.	c #D9D9D9",
"=.	c #EBEBEB",
"-.	c #E9E9E9",
";.	c #D4D4D4",
">.	c #000000",
",.	c #E2E2E2",
"'.	c #DADADA",
").	c #CBCBCB",
"!.	c #3B3B3B",
"~.	c #D5D5D5",
"{.	c #C8C8C8",
"].	c #BDBDBD",
"^.	c #515151",
"/.	c #C7C7C7",
"(.	c #CDCDCD",
"_.	c #B8B8B8",
":.	c #030303",
"<.	c #313131",
"[.	c #999999",
"}.	c #BBBBBB",
"|.	c #B6B6B6",
"1.	c #909090",
"2.	c #2B2B2B",
"3.	c #010101",
"4.	c #7A7A7A",
"5.	c #9A9A9A",
"6.	c #777777",
"7.	c #3C3C3C",
"8.	c #686868",
"9.	c #797979",
"0.	c #3A3A3A",
"                                                ",
"              . + @ # # #                       ",
"          $ % & * = - ; > , '                   ",
"        ) ! = ~ { ] ^ / ( _ : <                 ",
"      [ } ~ | 1 2 3 4 5 6 7 8 9 0               ",
"    a b c d 6 e f g f h e i j k l m             ",
"    n o p 2 q g r r s g h t u v w x             ",
"  y z 7 j e f r A A r s q e B C 1 D E           ",
"  F G H B I q s A A r g h J B C K L M           ",
"  N O P 3 e Q Q R R R Q l S T 6 1 U M           ",
"  x V W u t l Q Q Q Q l S X Y Z d `  .          ",
"  ..+.j 2 T 5 J I I e 4 3 u v 1 @.#.$.          ",
"  %.&.*.j C =.B 3 3 B T -.v 1 ;.~ : >.          ",
"    %.= H K ,.6 C C 2 W P '.;.).* $.            ",
"    M !.c 7 ;.'.1 '.1 H ~.] {.].$ >.            ",
"       .^.k /.).c (.).).{.k _.R >.              ",
"        :.<.[.}.].8 8 8 |.1.2.>.>.>.            ",
"          3.:.X 4.5.5.6.7.>.>.  >.>.>.>.        ",
"              >.>.>.>.>.>.        , , >.>.      ",
"                                  >.8.. >.>.    ",
"                                    >.9.0.>.>.  ",
"                                      >.8.n >.  ",
"                                        >.>.    ",
"                                                "};

/* XPM */
static char * icon_zoomout[] = {
"24 24 132 2",
"  	c None",
". 	c #343434",
"+ 	c #2D2D2D",
"@ 	c #292929",
"# 	c #262626",
"$ 	c #2E2E2E",
"% 	c #303030",
"& 	c #737373",
"* 	c #A1A1A1",
"= 	c #B4B4B4",
"- 	c #B2B2B2",
"; 	c #9D9D9D",
"> 	c #676767",
", 	c #202020",
"' 	c #1C1C1C",
") 	c #272727",
"! 	c #616161",
"~ 	c #CACACA",
"{ 	c #CFCFCF",
"] 	c #D0D0D0",
"^ 	c #CECECE",
"/ 	c #C9C9C9",
"( 	c #C1C1C1",
"_ 	c #A7A7A7",
": 	c #4C4C4C",
"< 	c #131313",
"[ 	c #222222",
"} 	c #757575",
"| 	c #D3D3D3",
"1 	c #DBDBDB",
"2 	c #E7E7E7",
"3 	c #EFEFEF",
"4 	c #F3F3F3",
"5 	c #F1F1F1",
"6 	c #E5E5E5",
"7 	c #D2D2D2",
"8 	c #BCBCBC",
"9 	c #5E5E5E",
"0 	c #101010",
"a 	c #212121",
"b 	c #5B5B5B",
"c 	c #CCCCCC",
"d 	c #D7D7D7",
"e 	c #F5F5F5",
"f 	c #FAFAFA",
"g 	c #FBFBFB",
"h 	c #F8F8F8",
"i 	c #F0F0F0",
"j 	c #E1E1E1",
"k 	c #C2C2C2",
"l 	c #434343",
"m 	c #0F0F0F",
"n 	c #1F1F1F",
"o 	c #B9B9B9",
"p 	c #D6D6D6",
"q 	c #F9F9F9",
"r 	c #FDFDFD",
"s 	c #454545",
"t 	c #F2F2F2",
"u 	c #ECECEC",
"v 	c #E4E4E4",
"w 	c #ABABAB",
"x 	c #0E0E0E",
"y 	c #1B1B1B",
"z 	c #6D6D6D",
"A 	c #FEFEFE",
"B 	c #FCFCFC",
"C 	c #EEEEEE",
"D 	c #E6E6E6",
"E 	c #575757",
"F 	c #090909",
"G 	c #141414",
"H 	c #A8A8A8",
"I 	c #D8D8D8",
"J 	c #F6F6F6",
"K 	c #F4F4F4",
"L 	c #DCDCDC",
"M 	c #9B9B9B",
"N 	c #060606",
"O 	c #111111",
"P 	c #C5C5C5",
"Q 	c #DFDFDF",
"R 	c #444444",
"S 	c #424242",
"T 	c #EDEDED",
"U 	c #BFBFBF",
"V 	c #C6C6C6",
"W 	c #E3E3E3",
"X 	c #414141",
"Y 	c #EAEAEA",
"Z 	c #E0E0E0",
"` 	c #BABABA",
" .	c #050505",
"..	c #0B0B0B",
"+.	c #A5A5A5",
"@.	c #D1D1D1",
"#.	c #939393",
"$.	c #020202",
"%.	c #0A0A0A",
"&.	c #5F5F5F",
"*.	c #D9D9D9",
"=.	c #EBEBEB",
"-.	c #E9E9E9",
";.	c #D4D4D4",
">.	c #000000",
",.	c #E2E2E2",
"'.	c #3F3F3F",
").	c #DADADA",
"!.	c #CBCBCB",
"~.	c #3B3B3B",
"{.	c #D5D5D5",
"].	c #C8C8C8",
"^.	c #BDBDBD",
"/.	c #515151",
"(.	c #C7C7C7",
"_.	c #CDCDCD",
":.	c #B8B8B8",
"<.	c #030303",
"[.	c #313131",
"}.	c #999999",
"|.	c #BBBBBB",
"1.	c #B6B6B6",
"2.	c #909090",
"3.	c #2B2B2B",
"4.	c #010101",
"5.	c #7A7A7A",
"6.	c #9A9A9A",
"7.	c #777777",
"8.	c #3C3C3C",
"9.	c #686868",
"0.	c #797979",
"a.	c #3A3A3A",
"                                                ",
"              . + @ # # #                       ",
"          $ % & * = - ; > , '                   ",
"        ) ! = ~ { ] ^ / ( _ : <                 ",
"      [ } ~ | 1 2 3 4 5 6 7 8 9 0               ",
"    a b c d 6 e f g f h e i j k l m             ",
"    n o p 2 q g r s s g h t u v w x             ",
"  y z 7 j e f r A s s B q e C D 1 E F           ",
"  G H I C J q B A s s g h K C D L M N           ",
"  O P Q 3 e R R s s s R l S T 6 1 U N           ",
"  x V W u t l R R R R l S X Y Z d `  .          ",
"  ..+.j 2 T 5 K J l l 4 3 u v 1 @.#.$.          ",
"  %.&.*.j D =.C 3 X X T -.v 1 ;.~ : >.          ",
"    %.= I L ,.6 D '.'.W Q ).;.!.* $.            ",
"    N ~.c 7 ;.).1 ).1 I {.] ].^.$ >.            ",
"       ./.k (.!.c _.!.!.].k :.s >.              ",
"        <.[.}.|.^.8 8 8 1.2.3.>.>.>.            ",
"          4.<.X 5.6.6.7.8.>.>.  >.>.>.>.        ",
"              >.>.>.>.>.>.        , , >.>.      ",
"                                  >.9.. >.>.    ",
"                                    >.0.a.>.>.  ",
"                                      >.9.n >.  ",
"                                        >.>.    ",
"                                                "};

/* XPM */
static char * icon_zoomfit[] = {
"24 24 140 2",
"  	c None",
". 	c #343434",
"+ 	c #2D2D2D",
"@ 	c #292929",
"# 	c #262626",
"$ 	c #2E2E2E",
"% 	c #303030",
"& 	c #737373",
"* 	c #A1A1A1",
"= 	c #B4B4B4",
"- 	c #B2B2B2",
"; 	c #9D9D9D",
"> 	c #676767",
", 	c #202020",
"' 	c #1C1C1C",
") 	c #272727",
"! 	c #616161",
"~ 	c #CACACA",
"{ 	c #CFCFCF",
"] 	c #D0D0D0",
"^ 	c #CECECE",
"/ 	c #C9C9C9",
"( 	c #C1C1C1",
"_ 	c #A7A7A7",
": 	c #4C4C4C",
"< 	c #131313",
"[ 	c #222222",
"} 	c #757575",
"| 	c #D3D3D3",
"1 	c #DBDBDB",
"2 	c #E7E7E7",
"3 	c #EFEFEF",
"4 	c #F3F3F3",
"5 	c #F1F1F1",
"6 	c #E5E5E5",
"7 	c #D2D2D2",
"8 	c #BCBCBC",
"9 	c #5E5E5E",
"0 	c #101010",
"a 	c #212121",
"b 	c #5B5B5B",
"c 	c #CCCCCC",
"d 	c #464646",
"e 	c #4B4B4B",
"f 	c #505050",
"g 	c #525252",
"h 	c #FBFBFB",
"i 	c #FAFAFA",
"j 	c #515151",
"k 	c #4F4F4F",
"l 	c #4A4A4A",
"m 	c #C2C2C2",
"n 	c #434343",
"o 	c #0F0F0F",
"p 	c #1F1F1F",
"q 	c #B9B9B9",
"r 	c #D6D6D6",
"s 	c #535353",
"t 	c #FDFDFD",
"u 	c #FCFCFC",
"v 	c #4D4D4D",
"w 	c #E4E4E4",
"x 	c #ABABAB",
"y 	c #0E0E0E",
"z 	c #1B1B1B",
"A 	c #6D6D6D",
"B 	c #E1E1E1",
"C 	c #FEFEFE",
"D 	c #F9F9F9",
"E 	c #4E4E4E",
"F 	c #E6E6E6",
"G 	c #575757",
"H 	c #090909",
"I 	c #141414",
"J 	c #A8A8A8",
"K 	c #D8D8D8",
"L 	c #EEEEEE",
"M 	c #F8F8F8",
"N 	c #DCDCDC",
"O 	c #9B9B9B",
"P 	c #060606",
"Q 	c #111111",
"R 	c #C5C5C5",
"S 	c #DFDFDF",
"T 	c #F5F5F5",
"U 	c #F7F7F7",
"V 	c #F2F2F2",
"W 	c #EDEDED",
"X 	c #BFBFBF",
"Y 	c #C6C6C6",
"Z 	c #E3E3E3",
"` 	c #ECECEC",
" .	c #F4F4F4",
"..	c #F0F0F0",
"+.	c #EAEAEA",
"@.	c #E0E0E0",
"#.	c #D7D7D7",
"$.	c #BABABA",
"%.	c #050505",
"&.	c #0B0B0B",
"*.	c #A5A5A5",
"=.	c #F6F6F6",
"-.	c #D1D1D1",
";.	c #939393",
">.	c #020202",
",.	c #0A0A0A",
"'.	c #5F5F5F",
").	c #D9D9D9",
"!.	c #E9E9E9",
"~.	c #484848",
"{.	c #D4D4D4",
"].	c #000000",
"^.	c #494949",
"/.	c #474747",
"(.	c #454545",
"_.	c #CBCBCB",
":.	c #3B3B3B",
"<.	c #DADADA",
"[.	c #444444",
"}.	c #414141",
"|.	c #BDBDBD",
"1.	c #C7C7C7",
"2.	c #CDCDCD",
"3.	c #C8C8C8",
"4.	c #B8B8B8",
"5.	c #030303",
"6.	c #313131",
"7.	c #999999",
"8.	c #BBBBBB",
"9.	c #B6B6B6",
"0.	c #909090",
"a.	c #2B2B2B",
"b.	c #010101",
"c.	c #7A7A7A",
"d.	c #9A9A9A",
"e.	c #777777",
"f.	c #3C3C3C",
"g.	c #686868",
"h.	c #797979",
"i.	c #3A3A3A",
"                                                ",
"              . + @ # # #                       ",
"          $ % & * = - ; > , '                   ",
"        ) ! = ~ { ] ^ / ( _ : <                 ",
"      [ } ~ | 1 2 3 4 5 6 7 8 9 0               ",
"    a b c d e f g h i j f k l m n o             ",
"    p q r : g g s t u g j k v w x y             ",
"  z A 7 B f g t C C t u D f E F 1 G H           ",
"  I J K L j g u C C t h M f E F N O P           ",
"  Q R S 3 T M h t t u i U V W 6 1 X P           ",
"  y Y Z ` V T M i i i U  ...+.@.#.$.%.          ",
"  &.*.B 2 E k  .=.=.T 4 3 v e 1 -.;.>.          ",
"  ,.'.).B e v L 3 3 L W !.e ~.{.~ : ].          ",
"    ,.= K ~.l e e F 2 l ^./.(._.* >.            ",
"    P :.c (.(./.~.<.1 /.d [.}.|.$ ].            ",
"      %.j m 1._.c 2._._.3.m 4.(.].              ",
"        5.6.7.8.|.8 8 8 9.0.a.].].].            ",
"          b.5.}.c.d.d.e.f.].].  ].].].].        ",
"              ].].].].].].        , , ].].      ",
"                                  ].g.. ].].    ",
"                                    ].h.i.].].  ",
"                                      ].g.p ].  ",
"                                        ].].    ",
"                                                "};

/* XPM */
static char * icon_zoomundo[] = {
"24 24 31 1",
" 	c None",
".	c #000000",
"+	c #EFE5BA",
"@	c #EFE7C1",
"#	c #EED680",
"$	c #EFE4B6",
"%	c #D5B75D",
"&	c #B29544",
"*	c #D1B051",
"=	c #C0AF73",
"-	c #C0A048",
";	c #986B07",
">	c #D1940C",
",	c #E0B74C",
"'	c #D9C374",
")	c #8F6406",
"!	c #D59D1C",
"~	c #B1933F",
"{	c #DFB74A",
"]	c #CCB76D",
"^	c #B8820A",
"/	c #D9A72E",
"(	c #D7A62C",
"_	c #C7B26A",
":	c #D4B150",
"<	c #A39256",
"[	c #E2CB79",
"}	c #C9B46B",
"|	c #8D7E4A",
"1	c #AE9C5C",
"2	c #96864F",
"                        ",
"                        ",
"                        ",
"          .             ",
"         ..             ",
"        .+.             ",
"       .@#....          ",
"      .$####%&.         ",
"     .+#######*.        ",
"    .=#########-.       ",
"     .;>>>>>>,#'..      ",
"      .)>>>>>>!#~.      ",
"       .)>...;>{].      ",
"        .;. ..^/#.      ",
"         ..  ..>#.      ",
"          .   .(_.      ",
"              .:<.      ",
"              .[.       ",
"             .}|.       ",
"            .12.        ",
"             ..         ",
"                        ",
"                        ",
"                        "};

/* XPM */
static char * zoom_larrow[] = {
"24 24 57 1",
" 	c None",
".	c #000000",
"+	c #F7F7F7",
"@	c #CBD6CA",
"#	c #E7EFE7",
"$	c #ACC8A9",
"%	c #C9DBC9",
"&	c #E6EEE5",
"*	c #BFCEBF",
"=	c #E7EFE6",
"-	c #BBCFBA",
";	c #B3C4B3",
">	c #E6EEE6",
",	c #B9CEB7",
"'	c #B5CEB5",
")	c #B7CCB5",
"!	c #BFD4BF",
"~	c #C7D7C5",
"{	c #DBE5DB",
"]	c #DAE5D9",
"^	c #CBDAC9",
"/	c #7EAB78",
"(	c #BAD1B9",
"_	c #B3CAB1",
":	c #B0C9B0",
"<	c #B0C9AE",
"[	c #AEC7AC",
"}	c #AAC5A8",
"|	c #A9C4A7",
"1	c #698267",
"2	c #E4ECE3",
"3	c #2D2D2D",
"4	c #E0EADE",
"5	c #B3CCB1",
"6	c #B0C7AE",
"7	c #ADC6AB",
"8	c #ADC8AB",
"9	c #AAC7A8",
"0	c #678C63",
"a	c #9FB79B",
"b	c #6B9063",
"c	c #C2CDC2",
"d	c #8EB48A",
"e	c #87AF84",
"f	c #87B083",
"g	c #88AF84",
"h	c #88B085",
"i	c #86AF82",
"j	c #547150",
"k	c #95A88F",
"l	c #5B7950",
"m	c #3C5235",
"n	c #4A6342",
"o	c #3B5035",
"p	c #415639",
"q	c #889D7F",
"r	c #475E3E",
"                        ",
"                        ",
"                        ",
"  ....        .         ",
"  .+@.       ..         ",
"  .#$.      .%.         ",
"  .#$.     .&*.         ",
"  .#$.    .=-;........  ",
"  .#$.   .>,'),!~{]^/.  ",
"  .#$.  .>(_:<[}}}[|1.  ",
"  .2$. 34567789[[6[80.  ",
"  .ab..cdeeeeefgefhij.  ",
"  .kl. .mllllllllllln.  ",
"  .kl.  .mlllllllllln.  ",
"  .kl.   .mllnoooooop.  ",
"  .kl.    .mln........  ",
"  .kl.     .mn.         ",
"  .kl.      .n.         ",
"  .qr.       ..         ",
"  ....        .         ",
"                        ",
"                        ",
"                        ",
"                        "};

/* XPM */
static char * zoom_rarrow[] = {
"24 24 52 1",
" 	c None",
".	c #000000",
"+	c #F7F7F7",
"@	c #CBD6CA",
"#	c #BECEBA",
"$	c #E7EFE7",
"%	c #ACC8A9",
"&	c #EBF2EA",
"*	c #77A16E",
"=	c #E3EBE2",
"-	c #709867",
";	c #F8F8F7",
">	c #F1F5F0",
",	c #ECF2EB",
"'	c #E5EEE3",
")	c #E0EBDF",
"!	c #D8E6D6",
"~	c #C6D9C2",
"{	c #C5D7C3",
"]	c #B2CBB0",
"^	c #AAC7A8",
"/	c #0F1308",
"(	c #DDE6DB",
"_	c #AEC8AD",
":	c #ABC7A8",
"<	c #AAC6A7",
"[	c #A8C6A5",
"}	c #ADC8AD",
"|	c #A8C7A8",
"1	c #A5C4A3",
"2	c #7F9F76",
"3	c #D6E1D4",
"4	c #ABC7AA",
"5	c #A7C5A4",
"6	c #A9C7A6",
"7	c #AFC8AD",
"8	c #A4C3A2",
"9	c #6B9060",
"0	c #E4ECE3",
"a	c #A7B6A2",
"b	c #698D60",
"c	c #6B9063",
"d	c #445B2C",
"e	c #9FB79B",
"f	c #9FB199",
"g	c #5B7950",
"h	c #95A88F",
"i	c #9FAF99",
"j	c #789171",
"k	c #506B46",
"l	c #889D7F",
"m	c #475E3E",
"                        ",
"                        ",
"                        ",
"        .        ....   ",
"        ..       .+@.   ",
"        .#.      .$%.   ",
"        .&*.     .$%.   ",
" ........=%-.    .$%.   ",
" .;>,')!~{]^-/   .$%.   ",
" .(_:::<[^}|12.  .$%.   ",
" .34[5[6:%^:789. .0%.   ",
" .abccccccccccbd..ec.   ",
" .fgggggggggggd. .hg.   ",
" .iggggggggggd.  .hg.   ",
" .jkkkkkkgggd.   .hg.   ",
" ........kgd.    .hg.   ",
"        .kd.     .hg.   ",
"        .d.      .hg.   ",
"        ..       .lm.   ",
"        .        ....   ",
"                        ",
"                        ",
"                        ",
"                        "};

/* XPM */
static char * prev_page_xpm[] = {
"24 24 170 2",
"  	c None",
". 	c #000000",
"+ 	c #040506",
"@ 	c #0B0F12",
"# 	c #959FAA",
"$ 	c #C3C6CA",
"% 	c #82909E",
"& 	c #F1F1F1",
"* 	c #D5D7D8",
"= 	c #0A0D10",
"- 	c #11171C",
"; 	c #8693A0",
"> 	c #EFF0F0",
", 	c #DEDEDE",
"' 	c #D5D5D5",
") 	c #9B9FA4",
"! 	c #0E1317",
"~ 	c #85929F",
"{ 	c #DBDBDB",
"] 	c #CACACA",
"^ 	c #C8C8C8",
"/ 	c #C8C9CA",
"( 	c #0C0F13",
"_ 	c #141A20",
": 	c #798895",
"< 	c #D2D2D2",
"[ 	c #C3C3C3",
"} 	c #CDCDCD",
"| 	c #74797E",
"1 	c #171F26",
"2 	c #7F8D9A",
"3 	c #DADADA",
"4 	c #D3D3D3",
"5 	c #C4C4C4",
"6 	c #CECECE",
"7 	c #C0C0C0",
"8 	c #B1B1B1",
"9 	c #0D1115",
"0 	c #768592",
"a 	c #EEEFEF",
"b 	c #D9D9D9",
"c 	c #D0D0D0",
"d 	c #C2C2C2",
"e 	c #CBCBCB",
"f 	c #C9C9C9",
"g 	c #BCBCBC",
"h 	c #A4A7A9",
"i 	c #686B6C",
"j 	c #333333",
"k 	c #414F5D",
"l 	c #ADB5BC",
"m 	c #EAEAEA",
"n 	c #BFBFBF",
"o 	c #BDBDBD",
"p 	c #C6C6C6",
"q 	c #B5B6B7",
"r 	c #899096",
"s 	c #B8B8B8",
"t 	c #FFFFFF",
"u 	c #404142",
"v 	c #4D6074",
"w 	c #EBEBEB",
"x 	c #D1D1D1",
"y 	c #C1C1C1",
"z 	c #B7B7B7",
"A 	c #979FA7",
"B 	c #A1A3A4",
"C 	c #FCFDFD",
"D 	c #F3F4F4",
"E 	c #EBECED",
"F 	c #EAEBEC",
"G 	c #E9EAEB",
"H 	c #EEEFF1",
"I 	c #F6F7F8",
"J 	c #E4E5E6",
"K 	c #929395",
"L 	c #32414F",
"M 	c #8C98A2",
"N 	c #E7E7E7",
"O 	c #BBBBBB",
"P 	c #A4A7AB",
"Q 	c #939699",
"R 	c #D7D8D8",
"S 	c #FAFCFC",
"T 	c #F9FAFB",
"U 	c #F8F9FA",
"V 	c #F7F8F9",
"W 	c #F5F6F8",
"X 	c #F7F7F9",
"Y 	c #C6C7C7",
"Z 	c #4F5E6A",
"` 	c #4C5F72",
" .	c #E8E8E8",
"..	c #BEBEBE",
"+.	c #1F1F1F",
"@.	c #B5B5B6",
"#.	c #979EA4",
"$.	c #A8A8A8",
"%.	c #FDFEFE",
"&.	c #F5F6F6",
"*.	c #E7E9E9",
"=.	c #F0F1F2",
"-.	c #E0E2E3",
";.	c #8F969D",
">.	c #151C22",
",.	c #354453",
"'.	c #8D99A2",
").	c #E3E3E3",
"!.	c #8E949A",
"~.	c #9D9F9F",
"{.	c #F2F3F4",
"].	c #F1F2F3",
"^.	c #F6F6F7",
"/.	c #A6A8AB",
"(.	c #737F8A",
"_.	c #4B5F71",
":.	c #CDDECB",
"<.	c #97999B",
"[.	c #E7E8E8",
"}.	c #F4F5F5",
"|.	c #FBFBFB",
"1.	c #D8D8DA",
"2.	c #939BA3",
"3.	c #0F1418",
"4.	c #B1C9B0",
"5.	c #E6E7E8",
"6.	c #FAFAFB",
"7.	c #F5F5F7",
"8.	c #AEB2B6",
"9.	c #5C6C7C",
"0.	c #B4CBB2",
"a.	c #B5CEB5",
"b.	c #B9CEB7",
"c.	c #BAD1BA",
"d.	c #BBD0B9",
"e.	c #B2C9B0",
"f.	c #7EAB78",
"g.	c #FBFCFC",
"h.	c #DEE1E3",
"i.	c #9DA6AE",
"j.	c #AAC7A8",
"k.	c #B3CAB1",
"l.	c #B0C9B0",
"m.	c #AEC7AC",
"n.	c #AAC5A8",
"o.	c #A9C4A7",
"p.	c #698267",
"q.	c #F9F9FA",
"r.	c #BBBFC4",
"s.	c #566779",
"t.	c #2D2D2D",
"u.	c #CFDFCC",
"v.	c #ADC8AB",
"w.	c #B0C7AE",
"x.	c #ADC6AB",
"y.	c #678C63",
"z.	c #D1D2D4",
"A.	c #9AA3AC",
"B.	c #3C5235",
"C.	c #5B7950",
"D.	c #4A6342",
"E.	c #E8ECEE",
"F.	c #B2B8BE",
"G.	c #717D88",
"H.	c #3B5035",
"I.	c #415639",
"J.	c #7A8695",
"K.	c #768594",
"L.	c #2C343D",
"M.	c #21272E",
"              . +                               ",
"            @ # $ .                             ",
"          @ % & * =                             ",
"        - ; > , ' ) .                           ",
"      ! ~ > { ] ^ / (                           ",
"    _ : & ' ] < [ } | .                         ",
"  1 2 > 3 4 5 6 7 ] 8 9                         ",
". 0 a b 4 c d e f g h i j . . . . . . .         ",
"k l m < n } e o p q r s t t t t t t t u .       ",
". v w x [ y ^ z [ A B C D E F G H I J K .       ",
"  L M N f O 5 d P Q R C S T U V W X Y Z .       ",
"  . `  .p ..+.@.#.$.%.&.*.E F =.U -.;.>..       ",
"    ,.'.).. . !.~.t %.C S {.].V ^./.(.+         ",
"    . _.. :.. <.b t [.a }.T U |.1.2.3.          ",
"      . :.4.. . . . . . . 5.6.7.8.9..           ",
"    . :.0.a.b.c.b.d.e.f.. T g.h.i.=             ",
"  . :.j.k.l.m.n.n.m.o.p.. g.q.r.s..             ",
"t.u.v.w.x.x.j.m.m.m.v.y.. t z.A.+               ",
"  . B.C.C.C.C.C.C.C.C.D.. E.F.G..               ",
"    . B.C.C.H.H.H.H.H.I.. J.K..                 ",
"      . B.C.. . . . . . . L.M.                  ",
"        . B..                                   ",
"          . .                                   ",
"            .                                   "};

/* XPM */
static char * next_page_xpm[] = {
"24 24 172 2",
"  	c None",
". 	c #000000",
"+ 	c #040506",
"@ 	c #0B0F12",
"# 	c #959FAA",
"$ 	c #C3C6CA",
"% 	c #82909E",
"& 	c #F1F1F1",
"* 	c #D5D7D8",
"= 	c #0A0D10",
"- 	c #11171C",
"; 	c #8693A0",
"> 	c #EFF0F0",
", 	c #DEDEDE",
"' 	c #D5D5D5",
") 	c #9B9FA4",
"! 	c #0E1317",
"~ 	c #85929F",
"{ 	c #DBDBDB",
"] 	c #CACACA",
"^ 	c #C8C8C8",
"/ 	c #C8C9CA",
"( 	c #0C0F13",
"_ 	c #141A20",
": 	c #798895",
"< 	c #D2D2D2",
"[ 	c #C3C3C3",
"} 	c #CDCDCD",
"| 	c #74797E",
"1 	c #171F26",
"2 	c #7F8D9A",
"3 	c #DADADA",
"4 	c #D3D3D3",
"5 	c #C4C4C4",
"6 	c #CECECE",
"7 	c #C0C0C0",
"8 	c #B1B1B1",
"9 	c #0D1115",
"0 	c #768592",
"a 	c #EEEFEF",
"b 	c #D9D9D9",
"c 	c #D0D0D0",
"d 	c #C2C2C2",
"e 	c #CBCBCB",
"f 	c #C9C9C9",
"g 	c #BCBCBC",
"h 	c #A4A7A9",
"i 	c #686B6C",
"j 	c #333333",
"k 	c #414F5D",
"l 	c #ADB5BC",
"m 	c #EAEAEA",
"n 	c #BFBFBF",
"o 	c #BDBDBD",
"p 	c #C6C6C6",
"q 	c #B5B6B7",
"r 	c #899096",
"s 	c #B8B8B8",
"t 	c #FFFFFF",
"u 	c #404142",
"v 	c #4D6074",
"w 	c #EBEBEB",
"x 	c #D1D1D1",
"y 	c #C1C1C1",
"z 	c #B7B7B7",
"A 	c #979FA7",
"B 	c #A1A3A4",
"C 	c #FCFDFD",
"D 	c #F3F4F4",
"E 	c #EBECED",
"F 	c #EAEBEC",
"G 	c #E9EAEB",
"H 	c #EEEFF1",
"I 	c #F6F7F8",
"J 	c #E4E5E6",
"K 	c #929395",
"L 	c #32414F",
"M 	c #8C98A2",
"N 	c #E7E7E7",
"O 	c #BBBBBB",
"P 	c #A4A7AB",
"Q 	c #939699",
"R 	c #D7D8D8",
"S 	c #FAFCFC",
"T 	c #F9FAFB",
"U 	c #F8F9FA",
"V 	c #F7F8F9",
"W 	c #F5F6F8",
"X 	c #F7F7F9",
"Y 	c #C6C7C7",
"Z 	c #4F5E6A",
"` 	c #4C5F72",
" .	c #E8E8E8",
"..	c #BEBEBE",
"+.	c #B5B5B6",
"@.	c #979EA4",
"#.	c #A8A8A8",
"$.	c #FDFEFE",
"%.	c #F5F6F6",
"&.	c #E7E9E9",
"*.	c #F0F1F2",
"=.	c #8F969D",
"-.	c #151C22",
";.	c #354453",
">.	c #8D99A2",
",.	c #E3E3E3",
"'.	c #8E949A",
").	c #9D9F9F",
"!.	c #F2F3F4",
"~.	c #F1F2F3",
"{.	c #F6F6F7",
"].	c #4B5F71",
"^.	c #E5E5E5",
"/.	c #9E9FA0",
"(.	c #97999B",
"_.	c #E7E8E8",
":.	c #F4F5F5",
"<.	c #FBFBFB",
"[.	c #D8D8DA",
"}.	c #77A16E",
"|.	c #394957",
"1.	c #828F97",
"2.	c #8A8E92",
"3.	c #B4B4B4",
"4.	c #ACC8A9",
"5.	c #709867",
"6.	c #4A5D70",
"7.	c #ABABAB",
"8.	c #F8F8F8",
"9.	c #C1D6BD",
"0.	c #BDD3B8",
"a.	c #BFD4BB",
"b.	c #C2D7BE",
"c.	c #B2CBB0",
"d.	c #AAC7A8",
"e.	c #0F1308",
"f.	c #242F3A",
"g.	c #696D71",
"h.	c #777879",
"i.	c #F2F3F3",
"j.	c #AEC5A8",
"k.	c #AEC8AD",
"l.	c #ABC7A8",
"m.	c #AAC6A7",
"n.	c #A8C6A5",
"o.	c #ADC8AD",
"p.	c #A8C7A8",
"q.	c #A5C4A3",
"r.	c #7F9F76",
"s.	c #4A5F74",
"t.	c #313E4B",
"u.	c #B3BDC6",
"v.	c #D1D7DD",
"w.	c #D9DEE3",
"x.	c #F6F7F7",
"y.	c #A6BFA0",
"z.	c #ABC7AA",
"A.	c #A9C7A6",
"B.	c #AFC8AD",
"C.	c #A4C3A2",
"D.	c #6B9060",
"E.	c #2B343C",
"F.	c #29323B",
"G.	c #4F5F70",
"H.	c #5E7184",
"I.	c #919EAB",
"J.	c #6C8562",
"K.	c #5B7950",
"L.	c #445B2C",
"M.	c #252D35",
"N.	c #65815C",
"O.	c #506B46",
"              . +                               ",
"            @ # $ .                             ",
"          @ % & * =                             ",
"        - ; > , ' ) .                           ",
"      ! ~ > { ] ^ / (                           ",
"    _ : & ' ] < [ } | .                         ",
"  1 2 > 3 4 5 6 7 ] 8 9                         ",
". 0 a b 4 c d e f g h i j . . . . . . .         ",
"k l m < n } e o p q r s t t t t t t t u .       ",
". v w x [ y ^ z [ A B C D E F G H I J K .       ",
"  L M N f O 5 d P Q R C S T U V W X Y Z .       ",
"  . `  .p ..s +.@.#.$.%.&.E F *.U . =.-..       ",
"    ;.>.,.y ..'.).t $.C S !.~.V {.. . +         ",
"    . ].^.y /.(.b t _.a :.T U <.[.. }..         ",
"      |.1.{ 2.3.t t $.. . . . . . . 4.5..       ",
"      . 6.O 7.t 8.& > . 9.0.a.b.b.b.c.d.5.e.    ",
"        f.g.h.i.t t t . j.k.l.l.m.n.o.p.q.r..   ",
"        . s.t.u.v.w.x.. y.z.n.n.A.l.d.l.B.C.D.. ",
"          . E.F.G.H.I.. J.K.K.K.K.K.K.K.K.L..   ",
"                . . M.. N.O.O.O.O.O.K.K.L..     ",
"                      . . . . . . . K.L..       ",
"                                  . L..         ",
"                                  . .           ",
"                                  .             "};

/* XPM */
static char * wave_info[] = {
"48 52 677 2",
"  	c None",
". 	c #000000",
"+ 	c #232323",
"@ 	c #1F1F1F",
"# 	c #DADADA",
"$ 	c #FFFFFF",
"% 	c #F6F6F6",
"& 	c #CFCFCF",
"* 	c #707070",
"= 	c #FEFEFE",
"- 	c #FBFBFB",
"; 	c #EDEDED",
"> 	c #C0C0C0",
", 	c #FF0000",
"' 	c #F7F7F7",
") 	c #D7D7D7",
"! 	c #F1F1F1",
"~ 	c #B7B7B7",
"{ 	c #D2D2D2",
"] 	c #AEAEAE",
"^ 	c #070707",
"/ 	c #FDFDFD",
"( 	c #B8B8B8",
"_ 	c #DCDCDC",
": 	c #A4A4A3",
"< 	c #0E0E0E",
"[ 	c #F5F5F4",
"} 	c #B5B5B5",
"| 	c #F9F9F9",
"1 	c #FCFCFC",
"2 	c #CBCBCB",
"3 	c #A5A5A5",
"4 	c #FDFDFC",
"5 	c #F4F4F4",
"6 	c #ACACAC",
"7 	c #ECECEC",
"8 	c #C3C3C3",
"9 	c #C2C2C2",
"0 	c #C9C9C8",
"a 	c #A8A8A8",
"b 	c #FCFCFB",
"c 	c #F4F4F3",
"d 	c #ABABAB",
"e 	c #515151",
"f 	c #474747",
"g 	c #464645",
"h 	c #464646",
"i 	c #5D5D5C",
"j 	c #A9A9A9",
"k 	c #FAFAFA",
"l 	c #F2F2F2",
"m 	c #F3F3F3",
"n 	c #AAAAAA",
"o 	c #A0A09F",
"p 	c #8A8A8A",
"q 	c #7A7A7A",
"r 	c #6C6C6C",
"s 	c #454545",
"t 	c #FAFAF9",
"u 	c #E7E7E7",
"v 	c #C6C6C5",
"w 	c #BABAB9",
"x 	c #F5F5F5",
"y 	c #EDEDEB",
"z 	c #B2B2B2",
"A 	c #949494",
"B 	c #7F7F7F",
"C 	c #8B8B8B",
"D 	c #8D8D8D",
"E 	c #EFEFEF",
"F 	c #737373",
"G 	c #727272",
"H 	c #666666",
"I 	c #4F4F4F",
"J 	c #4E4E4E",
"K 	c #4D4D4D",
"L 	c #505050",
"M 	c #CACACA",
"N 	c #4B4B4B",
"O 	c #4A4A4A",
"P 	c #4C4C4C",
"Q 	c #525252",
"R 	c #575757",
"S 	c #373737",
"T 	c #A1A1A1",
"U 	c #363636",
"V 	c #333333",
"W 	c #353535",
"X 	c #3F3F3F",
"Y 	c #5C5C5C",
"Z 	c #6B6B6B",
"` 	c #B1B1B1",
" .	c #A6A6A6",
"..	c #E4E4E4",
"+.	c #2E2E2E",
"@.	c #2D2D2D",
"#.	c #252525",
"$.	c #191919",
"%.	c #1B1B1B",
"&.	c #1C1C1C",
"*.	c #1E1E1E",
"=.	c #212121",
"-.	c #B9B9B9",
";.	c #1D1D1D",
">.	c #171717",
",.	c #242424",
"'.	c #222222",
").	c #919191",
"!.	c #292929",
"~.	c #F3F3F2",
"{.	c #9C9C9C",
"].	c #696969",
"^.	c #030303",
"/.	c #010101",
"(.	c #B0B0B0",
"_.	c #080808",
":.	c #060606",
"<.	c #868686",
"[.	c #040404",
"}.	c #0C0C0C",
"|.	c #2A2A2A",
"1.	c #F2F2F1",
"2.	c #979797",
"3.	c #5F5F5F",
"4.	c #131413",
"5.	c #222421",
"6.	c #2B302A",
"7.	c #B4BAB3",
"8.	c #2B312A",
"9.	c #2A3029",
"0.	c #292E28",
"a.	c #282D26",
"b.	c #272D26",
"c.	c #262C25",
"d.	c #252C24",
"e.	c #242B23",
"f.	c #242B22",
"g.	c #8B9289",
"h.	c #1E241D",
"i.	c #151814",
"j.	c #101010",
"k.	c #303030",
"l.	c #F1F1F0",
"m.	c #8E8E8E",
"n.	c #D4D4D4",
"o.	c #272A26",
"p.	c #495546",
"q.	c #64825E",
"r.	c #6B9063",
"s.	c #ABD3A2",
"t.	c #658D5C",
"u.	c #628C59",
"v.	c #608A56",
"w.	c #5E8B54",
"x.	c #598550",
"y.	c #57864D",
"z.	c #54844A",
"A.	c #518046",
"B.	c #4F8143",
"C.	c #84B779",
"D.	c #46773C",
"E.	c #344E2F",
"F.	c #1C241A",
"G.	c #F0F0F0",
"H.	c #848484",
"I.	c #D0D0D0",
"J.	c #262825",
"K.	c #5A6E56",
"L.	c #86C476",
"M.	c #8FE878",
"N.	c #8DEC74",
"O.	c #93F479",
"P.	c #84E66A",
"Q.	c #81E665",
"R.	c #7DE661",
"S.	c #7AE75C",
"T.	c #75E259",
"U.	c #72E653",
"V.	c #6EE14F",
"W.	c #6BE14A",
"X.	c #67E446",
"Y.	c #6FEC4D",
"Z.	c #60E53D",
"`.	c #53B13A",
" +	c #32522B",
".+	c #141A13",
"++	c #0B0B0B",
"@+	c #2B2B2B",
"#+	c #EFEFEE",
"$+	c #EFEFED",
"%+	c #777777",
"&+	c #CDCDCD",
"*+	c #414B3F",
"=+	c #7FB372",
"-+	c #93F778",
";+	c #90F974",
">+	c #8AF06F",
",+	c #90F474",
"'+	c #81E666",
")+	c #79E55C",
"!+	c #76E758",
"~+	c #71E153",
"{+	c #6FE64E",
"]+	c #67E145",
"^+	c #63E441",
"/+	c #69EE46",
"(+	c #60F537",
"_+	c #5AF032",
":+	c #449030",
"<+	c #20301D",
"[+	c #080908",
"}+	c #0A0A0A",
"|+	c #EEEEED",
"1+	c #EEEEEC",
"2+	c #FBFBFA",
"3+	c #747474",
"4+	c #313131",
"5+	c #1C1E1C",
"6+	c #586D53",
"7+	c #8AD676",
"8+	c #90FB73",
"9+	c #87E66E",
"0+	c #74B065",
"a+	c #9FD095",
"b+	c #5E8B53",
"c+	c #5A8850",
"d+	c #57864C",
"e+	c #548649",
"f+	c #508145",
"g+	c #4E8242",
"h+	c #4B7F3F",
"i+	c #487E3C",
"j+	c #47823A",
"k+	c #73C060",
"l+	c #56DA34",
"m+	c #58F72C",
"n+	c #4BBE2D",
"o+	c #284821",
"p+	c #0F140E",
"q+	c #343434",
"r+	c #414141",
"s+	c #EDEDEC",
"t+	c #E2E2E2",
"u+	c #D8D8D8",
"v+	c #C6C6C6",
"w+	c #BEBEBE",
"x+	c #BABABA",
"y+	c #BDC1BC",
"z+	c #B0D6A8",
"A+	c #96F57C",
"B+	c #8FFA72",
"C+	c #9AE089",
"D+	c #A7C0A2",
"E+	c #A6B0A3",
"F+	c #A0A79F",
"G+	c #9CA39B",
"H+	c #989E96",
"I+	c #949B92",
"J+	c #90978E",
"K+	c #878F85",
"L+	c #828B80",
"M+	c #7E8C7B",
"N+	c #799972",
"O+	c #67C750",
"P+	c #56F62C",
"Q+	c #56E92E",
"R+	c #619E53",
"S+	c #606C5E",
"T+	c #565756",
"U+	c #5A5A5A",
"V+	c #7B7B7B",
"W+	c #828282",
"X+	c #ECECEB",
"Y+	c #757575",
"Z+	c #3B4439",
"`+	c #77B069",
" @	c #8AF66D",
".@	c #84EC68",
"+@	c #65965A",
"@@	c #313C2F",
"#@	c #9C9D9C",
"$@	c #050505",
"%@	c #0D0F0C",
"&@	c #758672",
"*@	c #3D832D",
"=@	c #4DE625",
"-@	c #4AF21E",
";@	c #369320",
">@	c #182E13",
",@	c #050704",
"'@	c #121212",
")@	c #494949",
"!@	c #565656",
"~@	c #2C2C2C",
"{@	c #171917",
"]@	c #4D6149",
"^@	c #7FCE6C",
"/@	c #87FB68",
"(@	c #7DDB65",
"_@	c #53744C",
":@	c #1F241E",
"<@	c #959595",
"[@	c #020202",
"}@	c #70786E",
"|@	c #2E5B24",
"1@	c #45CA22",
"2@	c #48F719",
"3@	c #39B719",
"4@	c #1A3E12",
"5@	c #050C04",
"6@	c #141514",
"7@	c #595959",
"8@	c #EBEBEA",
"9@	c #F8F8F8",
"0@	c #5E5E5E",
"a@	c #BCBCBC",
"b@	c #638A5A",
"c@	c #82E867",
"d@	c #83FA62",
"e@	c #72C15E",
"f@	c #40543C",
"g@	c #151714",
"h@	c #6B6E6A",
"i@	c #203B1B",
"j@	c #39A51E",
"k@	c #42F112",
"l@	c #3AD410",
"m@	c #1E5C10",
"n@	c #061103",
"o@	c #111211",
"p@	c #555555",
"q@	c #EAEAE9",
"r@	c #EAEAE8",
"s@	c #F8F8F7",
"t@	c #5B5B5B",
"u@	c #0D0D0D",
"v@	c #3A4638",
"w@	c #71AE62",
"x@	c #81F563",
"y@	c #7DF15E",
"z@	c #64A155",
"A@	c #313D2E",
"B@	c #646664",
"C@	c #162813",
"D@	c #2C7919",
"E@	c #3ADE0E",
"F@	c #36DF09",
"G@	c #21780D",
"H@	c #091A05",
"I@	c #0E0F0D",
"J@	c #444444",
"K@	c #E9E9E8",
"L@	c #E9E9E7",
"M@	c #5D5D5D",
"N@	c #B6B6B6",
"O@	c #1A1C19",
"P@	c #4B6146",
"Q@	c #75C262",
"R@	c #7EF65D",
"S@	c #75DA5A",
"T@	c #517949",
"U@	c #212720",
"V@	c #0C160A",
"W@	c #1E5213",
"X@	c #30BA0C",
"Y@	c #33DD04",
"Z@	c #25890C",
"`@	c #0C2507",
" #	c #10130F",
".#	c #F6F6F5",
"+#	c #262B25",
"@#	c #5A8052",
"##	c #79E05E",
"$#	c #7BF957",
"%#	c #6BC554",
"&#	c #3E5639",
"*#	c #131613",
"=#	c #878787",
"-#	c #050A04",
";#	c #13350B",
">#	c #299E0B",
",#	c #32DA04",
"'#	c #2BB208",
")#	c #133D0A",
"!#	c #0F160E",
"~#	c #3E3E3E",
"{#	c #E8E8E7",
"]#	c #E8E8E6",
"^#	c #AFAFAF",
"/#	c #323D30",
"(#	c #66A257",
"_#	c #7AF458",
":#	c #75F553",
"<#	c #5EA44E",
"[#	c #2F3D2C",
"}#	c #0A0B0A",
"|#	c #838383",
"1#	c #585858",
"2#	c #010201",
"3#	c #091D06",
"4#	c #20720B",
"5#	c #30D004",
"6#	c #2FCB04",
"7#	c #1B610A",
"8#	c #0F1A0D",
"9#	c #404040",
"0#	c #131513",
"a#	c #3F513B",
"b#	c #6BB957",
"c#	c #75F752",
"d#	c #6EDC50",
"e#	c #4D7A43",
"f#	c #212A20",
"g#	c #808080",
"h#	c #545454",
"i#	c #040D02",
"j#	c #143F0A",
"k#	c #29A807",
"l#	c #2FCA04",
"m#	c #1F760A",
"n#	c #142511",
"o#	c #404240",
"p#	c #E7E7E6",
"q#	c #E6E6E4",
"r#	c #3C3C3C",
"s#	c #151515",
"t#	c #222721",
"u#	c #507348",
"v#	c #6FD654",
"w#	c #72F94D",
"x#	c #64C14B",
"y#	c #3B5836",
"z#	c #161A15",
"A#	c #7D7D7D",
"B#	c #010400",
"C#	c #0B2006",
"D#	c #218109",
"E#	c #2EC903",
"F#	c #249407",
"G#	c #163210",
"H#	c #3A3D3A",
"I#	c #565655",
"J#	c #E5E5E4",
"K#	c #CCCCCC",
"L#	c #C1C1C1",
"M#	c #B4B4B4",
"N#	c #AAABA9",
"O#	c #A8B5A5",
"P#	c #92D084",
"Q#	c #77F555",
"R#	c #73F84E",
"S#	c #84CE72",
"T#	c #93A38F",
"U#	c #8C8D8B",
"V#	c #7E7E7E",
"W#	c #797979",
"X#	c #717171",
"Y#	c #686868",
"Z#	c #636363",
"`#	c #424342",
" $	c #3A4538",
".$	c #337622",
"+$	c #2EBC08",
"@$	c #2DB00A",
"#$	c #2F5F23",
"$$	c #515750",
"%$	c #686867",
"&$	c #E1E1E0",
"*$	c #E3E3E2",
"=$	c #111111",
"-$	c #FBFDFA",
";$	c #EDF2EC",
">$	c #2E342D",
",$	c #575D56",
"'$	c #3F453E",
")$	c #2B322A",
"!$	c #2A3129",
"~$	c #2A3128",
"{$	c #293127",
"]$	c #A9B5A7",
"^$	c #466341",
"/$	c #66C050",
"($	c #6DFA47",
"_$	c #66E644",
":$	c #477D3C",
"<$	c #212A1F",
"[$	c #040403",
"}$	c #040504",
"|$	c #787978",
"1$	c #020302",
"2$	c #030801",
"3$	c #103807",
"4$	c #26A305",
"5$	c #2AB602",
"6$	c #1D6809",
"7$	c #283725",
"8$	c #3F443E",
"9$	c #CFD1CD",
"0$	c #D7D8D5",
"a$	c #323831",
"b$	c #E3F8DE",
"c$	c #CAEFC1",
"d$	c #6A9460",
"e$	c #7AA670",
"f$	c #6C9A62",
"g$	c #619057",
"h$	c #608F54",
"i$	c #5C8C51",
"j$	c #5A8C4E",
"k$	c #96CD89",
"l$	c #5EA44D",
"m$	c #69DF4A",
"n$	c #6AF945",
"o$	c #63C949",
"p$	c #45693D",
"q$	c #2C3B28",
"r$	c #1C2919",
"s$	c #1B2817",
"t$	c #1D2D1A",
"u$	c #7A8B76",
"v$	c #172614",
"w$	c #10190E",
"x$	c #152312",
"y$	c #1A2C15",
"z$	c #1C2C19",
"A$	c #1D291A",
"B$	c #1C2819",
"C$	c #172214",
"D$	c #152013",
"E$	c #515B4E",
"F$	c #111C0F",
"G$	c #111F0D",
"H$	c #15350D",
"I$	c #25850C",
"J$	c #2AB603",
"K$	c #218D05",
"L$	c #1E5111",
"M$	c #2B4D22",
"N$	c #0C2A04",
"O$	c #99B392",
"P$	c #AEBBA9",
"Q$	c #A6A7A5",
"R$	c #51644D",
"S$	c #B4F4A4",
"T$	c #9BF783",
"U$	c #88EC6D",
"V$	c #86EB6B",
"W$	c #81EC65",
"X$	c #7DE860",
"Y$	c #79E85B",
"Z$	c #75E757",
"`$	c #71E651",
" %	c #79F159",
".%	c #6BE84A",
"+%	c #6DF649",
"@%	c #6EF44A",
"#%	c #64BB4E",
"$%	c #4C7E3F",
"%%	c #39652E",
"&%	c #315C26",
"*%	c #2E5822",
"=%	c #2D5921",
"-%	c #73A266",
";%	c #2A591E",
">%	c #2C5821",
",%	c #3A6E2C",
"'%	c #407C30",
")%	c #427634",
"!%	c #38632E",
"~%	c #346029",
"{%	c #325D26",
"]%	c #305C24",
"^%	c #59864D",
"/%	c #2C591F",
"(%	c #2B5A1E",
"_%	c #28571B",
":%	c #265919",
"<%	c #2C7818",
"[%	c #2CAB08",
"}%	c #26A603",
"|%	c #259506",
"1%	c #288E0B",
"2%	c #1E8404",
"3%	c #42A029",
"4%	c #5EA14B",
"5%	c #90998D",
"6%	c #4F624A",
"7%	c #B0F49F",
"8%	c #97F77E",
"9%	c #84EB67",
"0%	c #83EA67",
"a%	c #7DEC60",
"b%	c #77E75A",
"c%	c #75E857",
"d%	c #70E552",
"e%	c #6DE64D",
"f%	c #74F053",
"g%	c #6BE44A",
"h%	c #71EC52",
"i%	c #6ACE51",
"j%	c #569546",
"k%	c #416E35",
"l%	c #336128",
"m%	c #315E24",
"n%	c #305F24",
"o%	c #2E5E21",
"p%	c #BEBCCB",
"q%	c #736F79",
"r%	c #2F362E",
"s%	c #DFF7DA",
"t%	c #C4EEBA",
"u%	c #619056",
"v%	c #71A165",
"w%	c #639558",
"x%	c #5B8E4F",
"y%	c #588D4C",
"z%	c #558A49",
"A%	c #538945",
"B%	c #8DC67F",
"C%	c #538A46",
"D%	c #59914C",
"E%	c #4F7846",
"F%	c #405A3A",
"G%	c #364A31",
"H%	c #34482F",
"I%	c #32472D",
"J%	c #32482D",
"K%	c #30462B",
"L%	c #625B81",
"M%	c #272534",
"N%	c #0F100F",
"O%	c #FAFDF9",
"P%	c #E8EEE5",
"Q%	c #2A3228",
"R%	c #60685F",
"S%	c #4C544A",
"T%	c #424B41",
"U%	c #434C42",
"V%	c #4F584D",
"W%	c #50594E",
"X%	c #ABB5A9",
"Y%	c #4C554A",
"Z%	c #3F473D",
"`%	c #373D36",
" &	c #3B3E3A",
".&	c #515450",
"+&	c #525652",
"@&	c #535652",
"#&	c #CAC8D5",
"$&	c #ECECEA",
"%&	c #555655",
"&&	c #383938",
"*&	c #474847",
"=&	c #626262",
"-&	c #616161",
";&	c #606060",
">&	c #A7A3B8",
",&	c #847F9C",
"'&	c #736D8E",
")&	c #DBDAE2",
"!&	c #9691AB",
"~&	c #EBEBE9",
"{&	c #B8B5C6",
"]&	c #E7E7E5",
"^&	c #E4E4E3",
"/&	c #E4E4E2",
"(&	c #EDECF0",
"_&	c #E5E5E3",
":&	c #E6E6E5",
"<&	c #E3E3E1",
"[&	c #A9A9A7",
"}&	c #A3A3A2",
"|&	c #A3A3A1",
"1&	c #E2E2E0",
"2&	c #E1E1DF",
"3&	c #9A9A9A",
"4&	c #8C8C8C",
"  . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . + @                       ",
". # $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ % & * .                   ",
". $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = - % ; > .                 ",
". $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = = ' ) $ ! ~ .               ",
". $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = = = = ' { $ $ ; ] ^             ",
". $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = = = = / / % ( $ / $ _ : <           ",
". $ $ $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = = / / / / / / [ } $ | 1 $ 2 3 .         ",
". $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = / / / / / 4 1 1 1 5 6 7 8 2 ( 9 0 a .       ",
". $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = / / / / / / 4 1 1 1 1 1 b c d e f g h h i j .       ",
". $ $ $ $ $ $ $ $ = = = = = = = = = = / / / / / 4 1 1 1 1 1 1 b - - k l m > n o p q r s .       ",
". $ $ $ $ $ $ = = = = = = = = / / / / / 1 / / / / 1 1 b - - - - k t t | - ' ' u v 0 w q .       ",
". $ $ . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . x y j .       ",
". $ $ . z A q B C D E F G H e I J K L K M N h h O P Q R P S T U V W U V W X Y Z . m m ` .       ",
". $ = .  .B R Q h S ..+.@.#.$.%.&.$.*.=.-.$.;.>.$.@ *.,.'.>.).;.>.$.;.>.$.!.X X . ~.~.} .       ",
". $ / . {.].U ;.^.. # . . . . . . /.^.^ (._.^ ^ :.^ :.^ ^ :.<.[.^.. . . . }.|.|.. 1.1.} .       ",
". $ / . 2.3.@ ^.. . ) . . . . . :.4.5.6.7.8.9.0.a.b.c.d.e.f.g.h.i._.. . . j.k.k.. l.l.} .       ",
". $ 1 . m.h ^.. . . n.. . . . _.o.p.q.r.s.t.u.v.w.x.y.z.A.B.C.D.E.F._.. . < @.@.. G.G.} .       ",
". $ b . H.V . . . . I.. . . [.J.K.L.M.N.O.P.Q.R.S.T.U.V.W.X.Y.Z.`. +.+/.. ++!.@+. #+$+} .       ",
". $ - . %+k.. . . . &+. . . j.*+=+-+;+>+,+'+R.)+!+~+{+W.]+^+/+(+_+:+<+[+. }+@+W . |+1+} .       ",
". $ 2+. 3+4+. . . . M . . /.5+6+7+8+9+0+a+b+c+d+e+f+g+h+i+j+k+l+m+n+o+p+. }+q+r+. s+s+} .       ",
". $ k . E t+u+n.& 2 v+9 w+x+y+z+A+B+C+D+E+F+G+H+I+J+g.K+L+M+N+O+P+Q+R+S+T+U+V+W+. 7 X+} .       ",
". $ t . Y+k.. . . . 8 . . < Z+`+ @.@+@@@#@^ :.^ $@^ :.:.:.%@&@*@=@-@;@>@,@'@)@!@. X+X+} .       ",
". $ | . Z ~@. . . . > . . {@]@^@/@(@_@:@<@. . . . . . . . [@}@|@1@2@3@4@5@6@P 7@. 8@8@} .       ",
". $ 9@. 0@#.. . . . a@. [.0.b@c@d@e@f@g@).. . . . . . . . . h@i@j@k@l@m@n@o@s p@. q@r@} .       ",
". $ s@. t@#.. . . . -.. u@v@w@x@y@z@A@++D . . . . . . . . . B@C@D@E@F@G@H@I@J@R . K@L@} .       ",
". $ % . M@!.. . . . N@/.O@P@Q@R@S@T@U@^.p . . . . . . . . . 0@V@W@X@Y@Z@`@ #J@t@. L@L@} .       ",
". $ .#. U++ . . . . z [.+#@###$#%#&#*#. =#. . . . . . . . . U+-#;#>#,#'#)#!#~#R . {#]#} .       ",
". $ x . t@#.. . . . ^#++/#(#_#:#<#[#}#. |#. . . . . . . . . 1#2#3#4#5#6#7#8#9#R . ]#]#} .       ",
". $ c . t@#.. . . . 6 0#a#b#c#d#e#f#[.. g#. . . . . . . . . h#. i#j#k#l#m#n#o#U+. p#q#} .       ",
". $ l . r#s#. . . . n t#u#v#w#x#y#z#/.. A#. . . . . . . . . e . B#C#D#E#F#G#H#I#. q#J#} .       ",
"[@= 1.^ K#L#-.M#(.6 N#O#P#Q#R#S#T#U#W+V#W#Y+X#r Y#Z#3.t@!@Q J )@`# $.$+$@$#$$$%$. &$*$} .       ",
"=$-$;$>$,$'$)$!$~${$]$^$/$($_$:$<$^ [$}$|$1$. . . . . . . . O . . 2$3$4$5$6$7$8$B#9$0$(..       ",
"a$b$c$d$e$f$g$h$i$j$k$l$m$n$o$p$q$r$s$t$u$v$w$x$y$z$A$B$C$D$E$w$F$G$H$I$J$K$L$M$N$O$P$Q$.       ",
"R$S$T$U$V$W$X$Y$Z$`$ %.%+%@%#%$%%%&%*%=%-%;%>%,%'%)%!%~%{%]%^%/%(%_%:%<%[%}%|%1%2%3%4%5%.       ",
"6%7%8%9%0%a%b%c%d%e%f%g%h%i%j%k%l%m%n%o%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%q%",
"r%s%t%u%v%w%x%y%z%A%B%C%D%E%F%G%H%I%J%K%p%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%M%",
"N%O%P%Q%R%S%T%U%V%W%X%Y%Z%`% &.&+&+&@&.&p%L%L%L%#&L%L%#&L%L%#&L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%M%",
"/.= $&^ %&`#&&*&=&-&( ;&`#q+r#h#R 1#R 7@p%L%L%L%>&,&'&)&>&L%#&L%'&!&'&L%,&L%L%,&L%'&,&L%L%L%L%M%",
". $ ~&. . . . . . . . . . . . . . . . . p%L%L%L%!&!&!&!&#&L%#&L%#&!&)&L%#&L%'&{&,&#&>&{&L%L%L%M%",
". $ q@q@q@r@r@K@K@{#]#]#]&q#q#J#^&/&/&/&p%L%L%L%L%#&{&'&#&!&!&L%,&{&(&L%{&,&{&,&#&!&!&)&L%L%L%M%",
". $ r@K@K@K@K@{#]#]#p#p#]&]&q#q#_&_&/&/&p%L%L%L%L%#&#&L%#&{&'&,&#&'&#&L%'&{&#&L%#&!&!&!&L%L%L%M%",
". $ K@K@K@]#p#p#p#p#]&]&]&:&:&q#_&_&_&_&p%L%L%L%L%>&{&L%,&)&L%,&#&>&(&'&L%#&>&L%,&#&!&)&L%L%L%M%",
". $ L@p#p#p#p#]&]&]&:&:&:&q#_&_&_&^&^&/&p%L%L%L%L%'&'&L%L%,&L%L%,&,&'&'&L%,&'&L%L%'&!&L%L%L%L%M%",
". $ p#]&]&]&:&:&:&:&q#q#_&^&^&^&/&/&/&/&p%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%M%",
". $ ]&:&:&:&q#q#q#q#^&^&/&/&/&/&/&/&/&/&q%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%",
". $ :&q#q#q#q#J#^&/&/&/&/&/&/&/&/&/&/&<&<&[&: }&}&}&}&|&|&|&        |&|&|&|&|&|&|&|&|&D . . .   ",
". # q#q#q#_&/&/&/&/&/&/&/&/&/&/&*$<&<&<&<&<&<&<&<&1&1&1&1&2&2&2&2&2&2&2&2&2&2&2&2&2&2&3&.       ",
". 9 } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } 3&4&.       ",
"  . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .       ",
"                                                                                                ",
"                                                                                                ",
"                                                                                                "};

/* XPM */
static char * wave_alert[] = {
"48 52 677 2",
"  	c None",
". 	c #000000",
"+ 	c #232323",
"@ 	c #1F1F1F",
"# 	c #DADADA",
"$ 	c #FFFFFF",
"% 	c #F6F6F6",
"& 	c #CFCFCF",
"* 	c #707070",
"= 	c #FEFEFE",
"- 	c #FBFBFB",
"; 	c #EDEDED",
"> 	c #C0C0C0",
", 	c #FF0000",
"' 	c #F7F7F7",
") 	c #D7D7D7",
"! 	c #F1F1F1",
"~ 	c #B7B7B7",
"{ 	c #D2D2D2",
"] 	c #AEAEAE",
"^ 	c #070707",
"/ 	c #FDFDFD",
"( 	c #B8B8B8",
"_ 	c #DCDCDC",
": 	c #A4A4A3",
"< 	c #0E0E0E",
"[ 	c #F5F5F4",
"} 	c #B5B5B5",
"| 	c #F9F9F9",
"1 	c #FCFCFC",
"2 	c #CBCBCB",
"3 	c #A5A5A5",
"4 	c #FDFDFC",
"5 	c #F4F4F4",
"6 	c #ACACAC",
"7 	c #ECECEC",
"8 	c #C3C3C3",
"9 	c #C2C2C2",
"0 	c #C9C9C8",
"a 	c #A8A8A8",
"b 	c #FCFCFB",
"c 	c #F4F4F3",
"d 	c #ABABAB",
"e 	c #515151",
"f 	c #474747",
"g 	c #464645",
"h 	c #464646",
"i 	c #5D5D5C",
"j 	c #A9A9A9",
"k 	c #FAFAFA",
"l 	c #F2F2F2",
"m 	c #F3F3F3",
"n 	c #AAAAAA",
"o 	c #A0A09F",
"p 	c #8A8A8A",
"q 	c #7A7A7A",
"r 	c #6C6C6C",
"s 	c #454545",
"t 	c #FAFAF9",
"u 	c #E7E7E7",
"v 	c #C6C6C5",
"w 	c #BABAB9",
"x 	c #F5F5F5",
"y 	c #EDEDEB",
"z 	c #B2B2B2",
"A 	c #949494",
"B 	c #7F7F7F",
"C 	c #8B8B8B",
"D 	c #8D8D8D",
"E 	c #EFEFEF",
"F 	c #737373",
"G 	c #727272",
"H 	c #666666",
"I 	c #4F4F4F",
"J 	c #4E4E4E",
"K 	c #4D4D4D",
"L 	c #505050",
"M 	c #CACACA",
"N 	c #4B4B4B",
"O 	c #4A4A4A",
"P 	c #4C4C4C",
"Q 	c #525252",
"R 	c #575757",
"S 	c #373737",
"T 	c #A1A1A1",
"U 	c #363636",
"V 	c #333333",
"W 	c #353535",
"X 	c #3F3F3F",
"Y 	c #5C5C5C",
"Z 	c #6B6B6B",
"` 	c #B1B1B1",
" .	c #A6A6A6",
"..	c #E4E4E4",
"+.	c #2E2E2E",
"@.	c #2D2D2D",
"#.	c #252525",
"$.	c #191919",
"%.	c #1B1B1B",
"&.	c #1C1C1C",
"*.	c #1E1E1E",
"=.	c #212121",
"-.	c #B9B9B9",
";.	c #1D1D1D",
">.	c #171717",
",.	c #242424",
"'.	c #222222",
").	c #919191",
"!.	c #292929",
"~.	c #F3F3F2",
"{.	c #9C9C9C",
"].	c #696969",
"^.	c #030303",
"/.	c #010101",
"(.	c #B0B0B0",
"_.	c #080808",
":.	c #060606",
"<.	c #868686",
"[.	c #040404",
"}.	c #0C0C0C",
"|.	c #2A2A2A",
"1.	c #F2F2F1",
"2.	c #979797",
"3.	c #5F5F5F",
"4.	c #131413",
"5.	c #222421",
"6.	c #2B302A",
"7.	c #B4BAB3",
"8.	c #2B312A",
"9.	c #2A3029",
"0.	c #292E28",
"a.	c #282D26",
"b.	c #272D26",
"c.	c #262C25",
"d.	c #252C24",
"e.	c #242B23",
"f.	c #242B22",
"g.	c #8B9289",
"h.	c #1E241D",
"i.	c #151814",
"j.	c #101010",
"k.	c #303030",
"l.	c #F1F1F0",
"m.	c #8E8E8E",
"n.	c #D4D4D4",
"o.	c #272A26",
"p.	c #495546",
"q.	c #64825E",
"r.	c #6B9063",
"s.	c #ABD3A2",
"t.	c #658D5C",
"u.	c #628C59",
"v.	c #608A56",
"w.	c #5E8B54",
"x.	c #598550",
"y.	c #57864D",
"z.	c #54844A",
"A.	c #518046",
"B.	c #4F8143",
"C.	c #84B779",
"D.	c #46773C",
"E.	c #344E2F",
"F.	c #1C241A",
"G.	c #F0F0F0",
"H.	c #848484",
"I.	c #D0D0D0",
"J.	c #262825",
"K.	c #5A6E56",
"L.	c #86C476",
"M.	c #8FE878",
"N.	c #8DEC74",
"O.	c #93F479",
"P.	c #84E66A",
"Q.	c #81E665",
"R.	c #7DE661",
"S.	c #7AE75C",
"T.	c #75E259",
"U.	c #72E653",
"V.	c #6EE14F",
"W.	c #6BE14A",
"X.	c #67E446",
"Y.	c #6FEC4D",
"Z.	c #60E53D",
"`.	c #53B13A",
" +	c #32522B",
".+	c #141A13",
"++	c #0B0B0B",
"@+	c #2B2B2B",
"#+	c #EFEFEE",
"$+	c #EFEFED",
"%+	c #777777",
"&+	c #CDCDCD",
"*+	c #414B3F",
"=+	c #7FB372",
"-+	c #93F778",
";+	c #90F974",
">+	c #8AF06F",
",+	c #90F474",
"'+	c #81E666",
")+	c #79E55C",
"!+	c #76E758",
"~+	c #71E153",
"{+	c #6FE64E",
"]+	c #67E145",
"^+	c #63E441",
"/+	c #69EE46",
"(+	c #60F537",
"_+	c #5AF032",
":+	c #449030",
"<+	c #20301D",
"[+	c #080908",
"}+	c #0A0A0A",
"|+	c #EEEEED",
"1+	c #EEEEEC",
"2+	c #FBFBFA",
"3+	c #747474",
"4+	c #313131",
"5+	c #1C1E1C",
"6+	c #586D53",
"7+	c #8AD676",
"8+	c #90FB73",
"9+	c #87E66E",
"0+	c #74B065",
"a+	c #9FD095",
"b+	c #5E8B53",
"c+	c #5A8850",
"d+	c #57864C",
"e+	c #548649",
"f+	c #508145",
"g+	c #4E8242",
"h+	c #4B7F3F",
"i+	c #487E3C",
"j+	c #47823A",
"k+	c #73C060",
"l+	c #56DA34",
"m+	c #58F72C",
"n+	c #4BBE2D",
"o+	c #284821",
"p+	c #0F140E",
"q+	c #343434",
"r+	c #414141",
"s+	c #EDEDEC",
"t+	c #E2E2E2",
"u+	c #D8D8D8",
"v+	c #C6C6C6",
"w+	c #BEBEBE",
"x+	c #BABABA",
"y+	c #BDC1BC",
"z+	c #B0D6A8",
"A+	c #96F57C",
"B+	c #8FFA72",
"C+	c #9AE089",
"D+	c #A7C0A2",
"E+	c #A6B0A3",
"F+	c #A0A79F",
"G+	c #9CA39B",
"H+	c #989E96",
"I+	c #949B92",
"J+	c #90978E",
"K+	c #878F85",
"L+	c #828B80",
"M+	c #7E8C7B",
"N+	c #799972",
"O+	c #67C750",
"P+	c #56F62C",
"Q+	c #56E92E",
"R+	c #619E53",
"S+	c #606C5E",
"T+	c #565756",
"U+	c #5A5A5A",
"V+	c #7B7B7B",
"W+	c #828282",
"X+	c #ECECEB",
"Y+	c #757575",
"Z+	c #3B4439",
"`+	c #77B069",
" @	c #8AF66D",
".@	c #84EC68",
"+@	c #65965A",
"@@	c #313C2F",
"#@	c #9C9D9C",
"$@	c #050505",
"%@	c #0D0F0C",
"&@	c #758672",
"*@	c #3D832D",
"=@	c #4DE625",
"-@	c #4AF21E",
";@	c #369320",
">@	c #182E13",
",@	c #050704",
"'@	c #121212",
")@	c #494949",
"!@	c #565656",
"~@	c #2C2C2C",
"{@	c #171917",
"]@	c #4D6149",
"^@	c #7FCE6C",
"/@	c #87FB68",
"(@	c #7DDB65",
"_@	c #53744C",
":@	c #1F241E",
"<@	c #959595",
"[@	c #020202",
"}@	c #70786E",
"|@	c #2E5B24",
"1@	c #45CA22",
"2@	c #48F719",
"3@	c #39B719",
"4@	c #1A3E12",
"5@	c #050C04",
"6@	c #141514",
"7@	c #595959",
"8@	c #EBEBEA",
"9@	c #F8F8F8",
"0@	c #5E5E5E",
"a@	c #BCBCBC",
"b@	c #638A5A",
"c@	c #82E867",
"d@	c #83FA62",
"e@	c #72C15E",
"f@	c #40543C",
"g@	c #151714",
"h@	c #6B6E6A",
"i@	c #203B1B",
"j@	c #39A51E",
"k@	c #42F112",
"l@	c #3AD410",
"m@	c #1E5C10",
"n@	c #061103",
"o@	c #111211",
"p@	c #555555",
"q@	c #EAEAE9",
"r@	c #EAEAE8",
"s@	c #F8F8F7",
"t@	c #5B5B5B",
"u@	c #0D0D0D",
"v@	c #3A4638",
"w@	c #71AE62",
"x@	c #81F563",
"y@	c #7DF15E",
"z@	c #64A155",
"A@	c #313D2E",
"B@	c #646664",
"C@	c #162813",
"D@	c #2C7919",
"E@	c #3ADE0E",
"F@	c #36DF09",
"G@	c #21780D",
"H@	c #091A05",
"I@	c #0E0F0D",
"J@	c #444444",
"K@	c #E9E9E8",
"L@	c #E9E9E7",
"M@	c #5D5D5D",
"N@	c #B6B6B6",
"O@	c #1A1C19",
"P@	c #4B6146",
"Q@	c #75C262",
"R@	c #7EF65D",
"S@	c #75DA5A",
"T@	c #517949",
"U@	c #212720",
"V@	c #0C160A",
"W@	c #1E5213",
"X@	c #30BA0C",
"Y@	c #33DD04",
"Z@	c #25890C",
"`@	c #0C2507",
" #	c #10130F",
".#	c #F6F6F5",
"+#	c #262B25",
"@#	c #5A8052",
"##	c #79E05E",
"$#	c #7BF957",
"%#	c #6BC554",
"&#	c #3E5639",
"*#	c #131613",
"=#	c #878787",
"-#	c #050A04",
";#	c #13350B",
">#	c #299E0B",
",#	c #32DA04",
"'#	c #2BB208",
")#	c #133D0A",
"!#	c #0F160E",
"~#	c #3E3E3E",
"{#	c #E8E8E7",
"]#	c #E8E8E6",
"^#	c #AFAFAF",
"/#	c #323D30",
"(#	c #66A257",
"_#	c #7AF458",
":#	c #75F553",
"<#	c #5EA44E",
"[#	c #2F3D2C",
"}#	c #0A0B0A",
"|#	c #838383",
"1#	c #585858",
"2#	c #010201",
"3#	c #091D06",
"4#	c #20720B",
"5#	c #30D004",
"6#	c #2FCB04",
"7#	c #1B610A",
"8#	c #0F1A0D",
"9#	c #404040",
"0#	c #131513",
"a#	c #3F513B",
"b#	c #6BB957",
"c#	c #75F752",
"d#	c #6EDC50",
"e#	c #4D7A43",
"f#	c #212A20",
"g#	c #808080",
"h#	c #545454",
"i#	c #040D02",
"j#	c #143F0A",
"k#	c #29A807",
"l#	c #2FCA04",
"m#	c #1F760A",
"n#	c #142511",
"o#	c #404240",
"p#	c #E7E7E6",
"q#	c #E6E6E4",
"r#	c #3C3C3C",
"s#	c #151515",
"t#	c #222721",
"u#	c #507348",
"v#	c #6FD654",
"w#	c #72F94D",
"x#	c #64C14B",
"y#	c #3B5836",
"z#	c #161A15",
"A#	c #7D7D7D",
"B#	c #010400",
"C#	c #0B2006",
"D#	c #218109",
"E#	c #2EC903",
"F#	c #249407",
"G#	c #163210",
"H#	c #3A3D3A",
"I#	c #565655",
"J#	c #E5E5E4",
"K#	c #CCCCCC",
"L#	c #C1C1C1",
"M#	c #B4B4B4",
"N#	c #AAABA9",
"O#	c #A8B5A5",
"P#	c #92D084",
"Q#	c #77F555",
"R#	c #73F84E",
"S#	c #84CE72",
"T#	c #93A38F",
"U#	c #8C8D8B",
"V#	c #7E7E7E",
"W#	c #797979",
"X#	c #717171",
"Y#	c #686868",
"Z#	c #636363",
"`#	c #424342",
" $	c #3A4538",
".$	c #337622",
"+$	c #2EBC08",
"@$	c #2DB00A",
"#$	c #2F5F23",
"$$	c #515750",
"%$	c #686867",
"&$	c #E1E1E0",
"*$	c #E3E3E2",
"=$	c #111111",
"-$	c #FBFDFA",
";$	c #EDF2EC",
">$	c #2E342D",
",$	c #575D56",
"'$	c #3F453E",
")$	c #2B322A",
"!$	c #2A3129",
"~$	c #2A3128",
"{$	c #293127",
"]$	c #A9B5A7",
"^$	c #466341",
"/$	c #66C050",
"($	c #6DFA47",
"_$	c #66E644",
":$	c #477D3C",
"<$	c #212A1F",
"[$	c #040403",
"}$	c #040504",
"|$	c #787978",
"1$	c #020302",
"2$	c #030801",
"3$	c #103807",
"4$	c #26A305",
"5$	c #2AB602",
"6$	c #1D6809",
"7$	c #283725",
"8$	c #3F443E",
"9$	c #CFD1CD",
"0$	c #D7D8D5",
"a$	c #323831",
"b$	c #E3F8DE",
"c$	c #CAEFC1",
"d$	c #6A9460",
"e$	c #7AA670",
"f$	c #6C9A62",
"g$	c #619057",
"h$	c #608F54",
"i$	c #5C8C51",
"j$	c #5A8C4E",
"k$	c #96CD89",
"l$	c #5EA44D",
"m$	c #69DF4A",
"n$	c #6AF945",
"o$	c #63C949",
"p$	c #45693D",
"q$	c #2C3B28",
"r$	c #1C2919",
"s$	c #1B2817",
"t$	c #1D2D1A",
"u$	c #7A8B76",
"v$	c #172614",
"w$	c #10190E",
"x$	c #152312",
"y$	c #1A2C15",
"z$	c #1C2C19",
"A$	c #1D291A",
"B$	c #1C2819",
"C$	c #172214",
"D$	c #152013",
"E$	c #515B4E",
"F$	c #111C0F",
"G$	c #111F0D",
"H$	c #15350D",
"I$	c #25850C",
"J$	c #2AB603",
"K$	c #218D05",
"L$	c #1E5111",
"M$	c #2B4D22",
"N$	c #0C2A04",
"O$	c #99B392",
"P$	c #AEBBA9",
"Q$	c #A6A7A5",
"R$	c #51644D",
"S$	c #B4F4A4",
"T$	c #9BF783",
"U$	c #88EC6D",
"V$	c #86EB6B",
"W$	c #81EC65",
"X$	c #7DE860",
"Y$	c #79E85B",
"Z$	c #75E757",
"`$	c #71E651",
" %	c #79F159",
".%	c #6BE84A",
"+%	c #6DF649",
"@%	c #6EF44A",
"#%	c #64BB4E",
"$%	c #4C7E3F",
"%%	c #39652E",
"&%	c #315C26",
"*%	c #2E5822",
"=%	c #2D5921",
"-%	c #73A266",
";%	c #2A591E",
">%	c #2C5821",
",%	c #3A6E2C",
"'%	c #407C30",
")%	c #427634",
"!%	c #38632E",
"~%	c #346029",
"{%	c #325D26",
"]%	c #305C24",
"^%	c #59864D",
"/%	c #2C591F",
"(%	c #2B5A1E",
"_%	c #28571B",
":%	c #265919",
"<%	c #2C7818",
"[%	c #2CAB08",
"}%	c #26A603",
"|%	c #259506",
"1%	c #288E0B",
"2%	c #1E8404",
"3%	c #42A029",
"4%	c #5EA14B",
"5%	c #90998D",
"6%	c #4F624A",
"7%	c #B0F49F",
"8%	c #97F77E",
"9%	c #84EB67",
"0%	c #83EA67",
"a%	c #7DEC60",
"b%	c #77E75A",
"c%	c #75E857",
"d%	c #70E552",
"e%	c #6DE64D",
"f%	c #74F053",
"g%	c #6BE44A",
"h%	c #71EC52",
"i%	c #6ACE51",
"j%	c #569546",
"k%	c #416E35",
"l%	c #336128",
"m%	c #315E24",
"n%	c #305F24",
"o%	c #2E5E21",
"p%	c #BEBCCB",
"q%	c #736F79",
"r%	c #2F362E",
"s%	c #DFF7DA",
"t%	c #C4EEBA",
"u%	c #619056",
"v%	c #71A165",
"w%	c #639558",
"x%	c #5B8E4F",
"y%	c #588D4C",
"z%	c #558A49",
"A%	c #538945",
"B%	c #8DC67F",
"C%	c #538A46",
"D%	c #59914C",
"E%	c #4F7846",
"F%	c #405A3A",
"G%	c #364A31",
"H%	c #34482F",
"I%	c #32472D",
"J%	c #32482D",
"K%	c #30462B",
"L%	c #625B81",
"M%	c #272534",
"N%	c #0F100F",
"O%	c #FAFDF9",
"P%	c #E8EEE5",
"Q%	c #2A3228",
"R%	c #60685F",
"S%	c #4C544A",
"T%	c #424B41",
"U%	c #434C42",
"V%	c #4F584D",
"W%	c #50594E",
"X%	c #ABB5A9",
"Y%	c #4C554A",
"Z%	c #3F473D",
"`%	c #373D36",
" &	c #3B3E3A",
".&	c #515450",
"+&	c #525652",
"@&	c #535652",
"#&	c #CAC8D5",
"$&	c #ECECEA",
"%&	c #555655",
"&&	c #383938",
"*&	c #474847",
"=&	c #626262",
"-&	c #616161",
";&	c #606060",
">&	c #A7A3B8",
",&	c #847F9C",
"'&	c #736D8E",
")&	c #DBDAE2",
"!&	c #9691AB",
"~&	c #EBEBE9",
"{&	c #B8B5C6",
"]&	c #E7E7E5",
"^&	c #E4E4E3",
"/&	c #E4E4E2",
"(&	c #EDECF0",
"_&	c #E5E5E3",
":&	c #E6E6E5",
"<&	c #E3E3E1",
"[&	c #A9A9A7",
"}&	c #A3A3A2",
"|&	c #A3A3A1",
"1&	c #E2E2E0",
"2&	c #E1E1DF",
"3&	c #9A9A9A",
"4&	c #8C8C8C",
"  . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . + @                       ",
". # $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ % & * .                   ",
". $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = - % ; > .                 ",
". $ $ $ , $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = = ' ) $ ! ~ .               ",
". $ $ $ , $ $ $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = = = = ' { $ $ ; ] ^             ",
". $ $ $ , $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = = = = / / % ( $ / $ _ : <           ",
". $ $ $ , $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = = / / / / / / [ } $ | 1 $ 2 3 .         ",
". $ $ $ $ $ $ $ $ $ $ $ $ = = = = = = = = = = = = = / / / / / 4 1 1 1 5 6 7 8 2 ( 9 0 a .       ",
". $ $ $ , $ $ $ $ $ $ = = = = = = = = = = = / / / / / / 4 1 1 1 1 1 b c d e f g h h i j .       ",
". $ $ $ $ $ $ $ $ = = = = = = = = = = / / / / / 4 1 1 1 1 1 1 b - - k l m > n o p q r s .       ",
". $ $ $ $ $ $ = = = = = = = = / / / / / 1 / / / / 1 1 b - - - - k t t | - ' ' u v 0 w q .       ",
". $ $ . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . x y j .       ",
". $ $ . z A q B C D E F G H e I J K L K M N h h O P Q R P S T U V W U V W X Y Z . m m ` .       ",
". $ = .  .B R Q h S ..+.@.#.$.%.&.$.*.=.-.$.;.>.$.@ *.,.'.>.).;.>.$.;.>.$.!.X X . ~.~.} .       ",
". $ / . {.].U ;.^.. # . . . . . . /.^.^ (._.^ ^ :.^ :.^ ^ :.<.[.^.. . . . }.|.|.. 1.1.} .       ",
". $ / . 2.3.@ ^.. . ) . . . . . :.4.5.6.7.8.9.0.a.b.c.d.e.f.g.h.i._.. . . j.k.k.. l.l.} .       ",
". $ 1 . m.h ^.. . . n.. . . . _.o.p.q.r.s.t.u.v.w.x.y.z.A.B.C.D.E.F._.. . < @.@.. G.G.} .       ",
". $ b . H.V . . . . I.. . . [.J.K.L.M.N.O.P.Q.R.S.T.U.V.W.X.Y.Z.`. +.+/.. ++!.@+. #+$+} .       ",
". $ - . %+k.. . . . &+. . . j.*+=+-+;+>+,+'+R.)+!+~+{+W.]+^+/+(+_+:+<+[+. }+@+W . |+1+} .       ",
". $ 2+. 3+4+. . . . M . . /.5+6+7+8+9+0+a+b+c+d+e+f+g+h+i+j+k+l+m+n+o+p+. }+q+r+. s+s+} .       ",
". $ k . E t+u+n.& 2 v+9 w+x+y+z+A+B+C+D+E+F+G+H+I+J+g.K+L+M+N+O+P+Q+R+S+T+U+V+W+. 7 X+} .       ",
". $ t . Y+k.. . . . 8 . . < Z+`+ @.@+@@@#@^ :.^ $@^ :.:.:.%@&@*@=@-@;@>@,@'@)@!@. X+X+} .       ",
". $ | . Z ~@. . . . > . . {@]@^@/@(@_@:@<@. . . . . . . . [@}@|@1@2@3@4@5@6@P 7@. 8@8@} .       ",
". $ 9@. 0@#.. . . . a@. [.0.b@c@d@e@f@g@).. . . . . . . . . h@i@j@k@l@m@n@o@s p@. q@r@} .       ",
". $ s@. t@#.. . . . -.. u@v@w@x@y@z@A@++D . . . . . . . . . B@C@D@E@F@G@H@I@J@R . K@L@} .       ",
". $ % . M@!.. . . . N@/.O@P@Q@R@S@T@U@^.p . . . . . . . . . 0@V@W@X@Y@Z@`@ #J@t@. L@L@} .       ",
". $ .#. U++ . . . . z [.+#@###$#%#&#*#. =#. . . . . . . . . U+-#;#>#,#'#)#!#~#R . {#]#} .       ",
". $ x . t@#.. . . . ^#++/#(#_#:#<#[#}#. |#. . . . . . . . . 1#2#3#4#5#6#7#8#9#R . ]#]#} .       ",
". $ c . t@#.. . . . 6 0#a#b#c#d#e#f#[.. g#. . . . . . . . . h#. i#j#k#l#m#n#o#U+. p#q#} .       ",
". $ l . r#s#. . . . n t#u#v#w#x#y#z#/.. A#. . . . . . . . . e . B#C#D#E#F#G#H#I#. q#J#} .       ",
"[@= 1.^ K#L#-.M#(.6 N#O#P#Q#R#S#T#U#W+V#W#Y+X#r Y#Z#3.t@!@Q J )@`# $.$+$@$#$$$%$. &$*$} .       ",
"=$-$;$>$,$'$)$!$~${$]$^$/$($_$:$<$^ [$}$|$1$. . . . . . . . O . . 2$3$4$5$6$7$8$B#9$0$(..       ",
"a$b$c$d$e$f$g$h$i$j$k$l$m$n$o$p$q$r$s$t$u$v$w$x$y$z$A$B$C$D$E$w$F$G$H$I$J$K$L$M$N$O$P$Q$.       ",
"R$S$T$U$V$W$X$Y$Z$`$ %.%+%@%#%$%%%&%*%=%-%;%>%,%'%)%!%~%{%]%^%/%(%_%:%<%[%}%|%1%2%3%4%5%.       ",
"6%7%8%9%0%a%b%c%d%e%f%g%h%i%j%k%l%m%n%o%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%p%q%",
"r%s%t%u%v%w%x%y%z%A%B%C%D%E%F%G%H%I%J%K%p%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%M%",
"N%O%P%Q%R%S%T%U%V%W%X%Y%Z%`% &.&+&+&@&.&p%L%L%L%#&L%L%#&L%L%#&L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%M%",
"/.= $&^ %&`#&&*&=&-&( ;&`#q+r#h#R 1#R 7@p%L%L%L%>&,&'&)&>&L%#&L%'&!&'&L%,&L%L%,&L%'&,&L%L%L%L%M%",
". $ ~&. . . . . . . . . . . . . . . . . p%L%L%L%!&!&!&!&#&L%#&L%#&!&)&L%#&L%'&{&,&#&>&{&L%L%L%M%",
". $ q@q@q@r@r@K@K@{#]#]#]&q#q#J#^&/&/&/&p%L%L%L%L%#&{&'&#&!&!&L%,&{&(&L%{&,&{&,&#&!&!&)&L%L%L%M%",
". $ r@K@K@K@K@{#]#]#p#p#]&]&q#q#_&_&/&/&p%L%L%L%L%#&#&L%#&{&'&,&#&'&#&L%'&{&#&L%#&!&!&!&L%L%L%M%",
". $ K@K@K@]#p#p#p#p#]&]&]&:&:&q#_&_&_&_&p%L%L%L%L%>&{&L%,&)&L%,&#&>&(&'&L%#&>&L%,&#&!&)&L%L%L%M%",
". $ L@p#p#p#p#]&]&]&:&:&:&q#_&_&_&^&^&/&p%L%L%L%L%'&'&L%L%,&L%L%,&,&'&'&L%,&'&L%L%'&!&L%L%L%L%M%",
". $ p#]&]&]&:&:&:&:&q#q#_&^&^&^&/&/&/&/&p%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%L%M%",
". $ ]&:&:&:&q#q#q#q#^&^&/&/&/&/&/&/&/&/&q%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%M%",
". $ :&q#q#q#q#J#^&/&/&/&/&/&/&/&/&/&/&<&<&[&: }&}&}&}&|&|&|&        |&|&|&|&|&|&|&|&|&D . . .   ",
". # q#q#q#_&/&/&/&/&/&/&/&/&/&/&*$<&<&<&<&<&<&<&<&1&1&1&1&2&2&2&2&2&2&2&2&2&2&2&2&2&2&3&.       ",
". 9 } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } } 3&4&.       ",
"  . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .       ",
"                                                                                                ",
"                                                                                                ",
"                                                                                                "};


void make_pixmaps(GtkWidget *window)
{
GtkStyle *style;

style=gtk_widget_get_style(window);

GLOBALS->redo_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->redo_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)icon_redo);

GLOBALS->larrow_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->larrow_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)icon_larrow);
GLOBALS->rarrow_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->rarrow_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)icon_rarrow);

GLOBALS->zoomout_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->zoomout_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)icon_zoomout);
GLOBALS->zoomin_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->zoomin_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)icon_zoomin);
GLOBALS->zoomfit_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->zoomfit_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)icon_zoomfit);
GLOBALS->zoomundo_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->zoomundo_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)icon_zoomundo);

GLOBALS->zoom_larrow_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->zoom_larrow_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)zoom_larrow);
GLOBALS->zoom_rarrow_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->zoom_rarrow_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)zoom_rarrow);

GLOBALS->prev_page_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->prev_page_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)prev_page_xpm);
GLOBALS->next_page_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->next_page_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)next_page_xpm);

GLOBALS->wave_info_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->wave_info_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)wave_info);
GLOBALS->wave_alert_pixmap=gdk_pixmap_create_from_xpm_d(window->window, &GLOBALS->wave_alert_mask,
	&style->bg[GTK_STATE_NORMAL], (gchar **)wave_alert);
}

/*
 * $Id: pixmaps.c,v 1.2 2007/08/26 21:35:43 gtkwave Exp $
 * $Log: pixmaps.c,v $
 * Revision 1.2  2007/08/26 21:35:43  gtkwave
 * integrated global context management from SystemOfCode2007 branch
 *
 * Revision 1.1.1.1.2.4  2007/08/26 19:05:55  gtkwave
 * added reload button in main window
 *
 * Revision 1.1.1.1.2.3  2007/08/07 03:18:55  kermin
 * Changed to pointer based GLOBAL structure and added initialization function
 *
 * Revision 1.1.1.1.2.2  2007/08/06 03:50:48  gtkwave
 * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
 * generated structs, etc.
 *
 * Revision 1.1.1.1.2.1  2007/08/05 02:27:21  kermin
 * Semi working global struct
 *
 * Revision 1.1.1.1  2007/05/30 04:27:53  gtkwave
 * Imported sources
 *
 * Revision 1.2  2007/04/20 02:08:13  gtkwave
 * initial release
 *
 */

